@@ -26,7 +26,7 @@ import datetime
 from hashlib import md5
 import operator
 
-from kiwi.datatypes import number, filter_locale
+from kiwi.datatypes import number
 from stoqdrivers.enum import TaxType
 from stoqlib.lib import latscii
 
@@ -327,15 +327,17 @@ class CATFile(object):
 
     # E21
     def add_payment_method(self, sale, fiscal_data,
-                           payment, renegotiation=None):
+                           payment, returned_sale=None):
         returned = 'N'
         returned_value = 0
+        # If the sale was returned, all payments were given back to the client
         if sale.return_date:
+            # Sales returned right after being emitted in the ECF dont have an
+            # invoice number, and they should not get this far.
+            invoice_number = returned_sale.invoice_number
+            assert invoice_number is None, invoice_number
             returned = 'S'
-            returned_value = renegotiation.paid_total
-            if renegotiation.penalty_value:
-                returned = 'P'
-                returned_value -= renegotiation.penalty_value
+            returned_value = payment.value
 
         self.add(CATRegisterE21(
             serial_number=self.printer.device_serial,
@@ -377,7 +379,7 @@ class CATFile(object):
         if filename is not None and fp is not None:
             raise TypeError
         if fp is None:
-            fp = open(filename, 'w')
+            fp = open(filename, 'wb')
 
         self._registers.sort(key=operator.attrgetter('register_type'))
 
@@ -454,8 +456,7 @@ class CATRegister(object):
             if value > max_value:
                 value = max_value
 
-            # Remove locale specific marks and replace the decimal digit dot.
-            str_value = filter_locale(str(value))
+            str_value = str(value)
             # Return to int again, so in the formatting we add the correct
             # numbers of zeros.
             re_value = int(str_value.replace('.', ''))
