@@ -33,13 +33,13 @@ from twisted.internet import reactor
 
 from stoqlib.net.xmlrpcservice import XMLRPCService
 from stoqlib.lib.osutils import get_application_dir
-from stoqlib.lib.parameters import is_developer_mode
+from stoqlib.lib.environment import is_developer_mode
 from stoqlib.lib.translation import stoqlib_gettext
 from stoq.lib.options import get_option_parser
 
 _ = stoqlib_gettext
 
-log = logging.getLogger('stoq.daemonmain')
+log = logging.getLogger(__name__)
 
 
 class Daemon(object):
