@@ -67,7 +67,7 @@ from twisted.internet.defer import succeed
 import stoq
 from stoq.gui.shell.statusbar import ShellStatusbar
 
-log = Logger('stoq.application')
+log = Logger(__name__)
 
 
 class App(object):
@@ -1389,8 +1389,7 @@ class SearchableAppWindow(AppWindow):
             else:
                 results = list(self.results)
 
-        self.print_report(self.report_table, self.results, results,
-                          do_footer=False)
+        self.print_report(self.report_table, self.results, results)
 
     def export_spreadsheet_activate(self):
         self.export_spread_sheet()
