@@ -23,7 +23,6 @@
 #
 """ Main gui definition for purchase application.  """
 
-import gettext
 import datetime
 from decimal import Decimal
 
@@ -62,12 +61,11 @@ from stoqlib.gui.wizards.purchasewizard import PurchaseWizard
 from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.permissions import PermissionManager
+from stoqlib.lib.translation import stoqlib_ngettext, stoqlib_gettext as _
 from stoqlib.reporting.purchase import PurchaseReport
 
 from stoq.gui.application import SearchableAppWindow
 
-_ = gettext.gettext
-
 
 class PurchaseApp(SearchableAppWindow):
 
@@ -181,7 +179,7 @@ class PurchaseApp(SearchableAppWindow):
         self.popup = self.uimanager.get_widget('/PurchaseSelection')
 
     def create_ui(self):
-        if api.sysparam(self.conn).SMART_LIST_LOADING:
+        if api.sysparam(self.store).SMART_LIST_LOADING:
             self.search.search.enable_lazy_search()
 
         self.app.launcher.add_new_items([
@@ -229,7 +227,7 @@ class PurchaseApp(SearchableAppWindow):
         self._new_order()
 
     def search_activate(self):
-        self.run_dialog(ProductSearch, self.conn, hide_price_column=True)
+        self.run_dialog(ProductSearch, self.store, hide_price_column=True)
 
     def search_completed(self, results, states):
         if len(results):
@@ -336,13 +334,14 @@ class PurchaseApp(SearchableAppWindow):
         self.Finish.set_sensitive(can_finish)
 
     def _new_order(self, order=None, edit_mode=False):
-        with api.trans() as trans:
-            order = trans.get(order)
-            self.run_dialog(PurchaseWizard, trans, order, edit_mode)
+        with api.trans() as store:
+            order = store.fetch(order)
+            self.run_dialog(PurchaseWizard, store, order, edit_mode)
 
-        if trans.committed:
+        if store.committed:
             self.refresh()
-            self.select_result(PurchaseOrderView.get(trans.retval.id, self.conn))
+            res = self.store.find(PurchaseOrderView, id=store.retval.id).one()
+            self.select_result(res)
 
     def _edit_order(self):
         selected = self.results.get_selected_rows()
@@ -362,7 +361,7 @@ class PurchaseApp(SearchableAppWindow):
         if qty != 1:
             raise ValueError('You should have only one order selected '
                              'at this point, got %d' % qty)
-        self.run_dialog(PurchaseDetailsDialog, self.conn,
+        self.run_dialog(PurchaseDetailsDialog, self.store,
                         model=order_views[0].purchase)
 
     def _send_selected_items_to_supplier(self):
@@ -375,20 +374,20 @@ class PurchaseApp(SearchableAppWindow):
             warning(_("There are no pending orders selected."))
             return
 
-        msg = gettext.ngettext(
+        msg = stoqlib_ngettext(
             _("The selected order will be marked as sent."),
             _("The %d selected orders will be marked as sent.")
             % len(valid_order_views),
             len(valid_order_views))
-        confirm_label = gettext.ngettext(_("Confirm order"),
+        confirm_label = stoqlib_ngettext(_("Confirm order"),
                                          _("Confirm orders"),
                                          len(valid_order_views))
         if yesno(msg, gtk.RESPONSE_NO, _("Don't confirm"), confirm_label):
             return
 
-        with api.trans() as trans:
+        with api.trans() as store:
             for order_view in valid_order_views:
-                order = trans.get(order_view.purchase)
+                order = store.fetch(order_view.purchase)
                 order.confirm()
         self.refresh()
         self.select_result(orders)
@@ -400,9 +399,9 @@ class PurchaseApp(SearchableAppWindow):
             raise ValueError('You should have only one order selected '
                              'at this point, got %d' % qty)
 
-        with api.trans() as trans:
-            order = trans.get(order_views[0].purchase)
-            self.run_dialog(PurchaseFinishWizard, trans, order)
+        with api.trans() as store:
+            order = store.fetch(order_views[0].purchase)
+            self.run_dialog(PurchaseFinishWizard, store, order)
 
         self.refresh()
         self.select_result(order_views)
@@ -410,17 +409,17 @@ class PurchaseApp(SearchableAppWindow):
     def _cancel_order(self):
         order_views = self.results.get_selected_rows()
         assert all(ov.purchase.can_cancel() for ov in order_views)
-        cancel_label = gettext.ngettext(_("Cancel order"),
+        cancel_label = stoqlib_ngettext(_("Cancel order"),
                                         _("Cancel orders"), len(order_views))
-        select_label = gettext.ngettext(_('The selected order will be cancelled.'),
+        select_label = stoqlib_ngettext(_('The selected order will be cancelled.'),
                                         _('The selected orders will be cancelled.'),
                                         len(order_views))
         if yesno(select_label, gtk.RESPONSE_NO,
                  _("Don't cancel"), cancel_label):
             return
-        with api.trans() as trans:
+        with api.trans() as store:
             for order_view in order_views:
-                order = trans.get(order_view.purchase)
+                order = store.fetch(order_view.purchase)
                 order.cancel()
         self._update_totals()
         self.refresh()
@@ -433,25 +432,27 @@ class PurchaseApp(SearchableAppWindow):
         return items
 
     def _quote_order(self, quote=None):
-        with api.trans() as trans:
-            quote = trans.get(quote)
-            self.run_dialog(QuotePurchaseWizard, trans, quote)
+        with api.trans() as store:
+            quote = store.fetch(quote)
+            self.run_dialog(QuotePurchaseWizard, store, quote)
 
-        if trans.committed:
+        if store.committed:
             self.refresh()
-            self.select_result(PurchaseOrderView.get(trans.retval.id, self.conn))
+            res = self.store.find(PurchaseOrderView, id=store.retval.id).one()
+            self.select_result(res)
 
     def _new_product(self):
-        with api.trans() as trans:
-            self.run_dialog(ProductEditor, trans, model=None)
+        with api.trans() as store:
+            self.run_dialog(ProductEditor, store, model=None)
 
     def _new_consignment(self):
-        with api.trans() as trans:
-            self.run_dialog(ConsignmentWizard, trans, model=None)
+        with api.trans() as store:
+            self.run_dialog(ConsignmentWizard, store, model=None)
 
-        if trans.committed:
+        if store.committed:
             self.refresh()
-            self.select_result(PurchaseOrderView.get(trans.retval.id, self.conn))
+            res = self.store.find(PurchaseOrderView, id=store.retval.id).one()
+            self.select_result(res)
 
     #
     # Kiwi Callbacks
@@ -494,63 +495,63 @@ class PurchaseApp(SearchableAppWindow):
     # Order
 
     def on_StockCost__activate(self, action):
-        self.run_dialog(StockCostDialog, self.conn, None)
+        self.run_dialog(StockCostDialog, self.store, None)
 
     # Consignment
 
     def on_CloseInConsignment__activate(self, action):
-        with api.trans() as trans:
-            self.run_dialog(CloseInConsignmentWizard, trans)
+        with api.trans() as store:
+            self.run_dialog(CloseInConsignmentWizard, store)
 
     def on_SearchInConsignmentItems__activate(self, action):
-        self.run_dialog(ConsignmentItemSearch, self.conn)
+        self.run_dialog(ConsignmentItemSearch, self.store)
 
     def on_Categories__activate(self, action):
-        self.run_dialog(SellableCategorySearch, self.conn)
+        self.run_dialog(SellableCategorySearch, self.store)
 
     def on_SearchQuotes__activate(self, action):
-        with api.trans() as trans:
-            self.run_dialog(ReceiveQuoteWizard, trans)
+        with api.trans() as store:
+            self.run_dialog(ReceiveQuoteWizard, store)
         self.refresh()
 
     def on_SearchPurchasedItems__activate(self, action):
-        self.run_dialog(PurchasedItemsSearch, self.conn)
+        self.run_dialog(PurchasedItemsSearch, self.store)
 
     def on_SearchStockItems__activate(self, action):
-        self.run_dialog(ProductStockSearch, self.conn)
+        self.run_dialog(ProductStockSearch, self.store)
 
     def on_SearchClosedStockItems__activate(self, action):
-        self.run_dialog(ProductClosedStockSearch, self.conn)
+        self.run_dialog(ProductClosedStockSearch, self.store)
 
     def on_Suppliers__activate(self, action):
-        self.run_dialog(SupplierSearch, self.conn, hide_footer=True)
+        self.run_dialog(SupplierSearch, self.store, hide_footer=True)
 
     def on_Products__activate(self, action):
-        self.run_dialog(ProductSearch, self.conn, hide_price_column=True)
+        self.run_dialog(ProductSearch, self.store, hide_price_column=True)
 
     def on_ProductUnits__activate(self, action):
-        self.run_dialog(SellableUnitSearch, self.conn)
+        self.run_dialog(SellableUnitSearch, self.store)
 
     def on_ProductManufacturers__activate(self, action):
-        self.run_dialog(ProductManufacturerDialog, self.conn)
+        self.run_dialog(ProductManufacturerDialog, self.store)
 
     def on_Services__activate(self, action):
-        self.run_dialog(ServiceSearch, self.conn, hide_price_column=True)
+        self.run_dialog(ServiceSearch, self.store, hide_price_column=True)
 
     def on_Transporter__activate(self, action):
-        self.run_dialog(TransporterSearch, self.conn, hide_footer=True)
+        self.run_dialog(TransporterSearch, self.store, hide_footer=True)
 
     def on_ProductsSoldSearch__activate(self, action):
-        self.run_dialog(ProductsSoldSearch, self.conn)
+        self.run_dialog(ProductsSoldSearch, self.store)
 
     def on_ProductsPriceSearch__activate(self, action):
         from stoqlib.domain.person import ClientCategory
-        if not ClientCategory.select(connection=self.conn).count():
+        if not self.store.find(ClientCategory).count():
             warning(_("Can't use prices editor without client categories"))
             return
 
-        with api.trans() as trans:
-            self.run_dialog(SellablePriceDialog, trans)
+        with api.trans() as store:
+            self.run_dialog(SellablePriceDialog, store)
 
     # Toolitem
 
