@@ -28,7 +28,6 @@ stoq/gui/receivable/receivable.py:
 """
 
 import datetime
-import gettext
 
 import pango
 import gtk
@@ -50,16 +49,15 @@ from stoqlib.gui.editors.paymentseditor import SalePaymentsEditor
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.search.paymentsearch import InPaymentBillCheckSearch
 from stoqlib.gui.search.paymentsearch import CardPaymentSearch
-from stoqlib.gui.slaves.installmentslave import SaleInstallmentConfirmationSlave
+from stoqlib.gui.slaves.paymentconfirmslave import SalePaymentConfirmSlave
 from stoqlib.gui.wizards.renegotiationwizard import PaymentRenegotiationWizard
 from stoqlib.lib.message import warning
+from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.payment import ReceivablePaymentReport
-from stoqlib.reporting.payments_receipt import InPaymentReceipt
+from stoqlib.reporting.paymentsreceipt import InPaymentReceipt
 
 from stoq.gui.accounts import BaseAccountWindow, FilterItem
 
-_ = gettext.gettext
-
 
 class ReceivableApp(BaseAccountWindow):
 
@@ -250,19 +248,19 @@ class ReceivableApp(BaseAccountWindow):
         """
         assert self._can_receive(receivable_views)
 
-        trans = api.new_transaction()
+        store = api.new_store()
 
-        payments = [trans.get(view.payment) for view in receivable_views]
+        payments = [store.fetch(view.payment) for view in receivable_views]
 
-        retval = run_dialog(SaleInstallmentConfirmationSlave, self, trans,
+        retval = run_dialog(SalePaymentConfirmSlave, self, store,
                             payments=payments)
 
-        if api.finish_transaction(trans, retval):
+        if store.confirm(retval):
             # We need to refresh the whole list as the payment(s) can possibly
             # disappear for the selected view
             self.refresh()
 
-        trans.close()
+        store.close()
         self._update_widgets()
 
     def _is_paid(self, receivable_view):
@@ -398,10 +396,10 @@ class ReceivableApp(BaseAccountWindow):
         return False
 
     def _run_card_payment_search(self):
-        run_dialog(CardPaymentSearch, self, self.conn)
+        run_dialog(CardPaymentSearch, self, self.store)
 
     def _run_bill_check_search(self):
-        run_dialog(InPaymentBillCheckSearch, self, self.conn)
+        run_dialog(InPaymentBillCheckSearch, self, self.store)
 
     def _update_filter_items(self):
         options = [
@@ -467,7 +465,7 @@ class ReceivableApp(BaseAccountWindow):
 
     def on_Renegotiate__activate(self, action):
         try:
-            Till.get_current(self.conn)
+            Till.get_current(self.store)
         except TillError, e:
             warning(str(e))
             return
@@ -475,34 +473,34 @@ class ReceivableApp(BaseAccountWindow):
         if not self._can_renegotiate(receivable_views):
             warning(_('Cannot renegotiate selected payments'))
             return
-        trans = api.new_transaction()
+        store = api.new_store()
 
-        groups = list(set([trans.get(v.group) for v in receivable_views]))
-        retval = run_dialog(PaymentRenegotiationWizard, self, trans,
+        groups = list(set([store.fetch(v.group) for v in receivable_views]))
+        retval = run_dialog(PaymentRenegotiationWizard, self, store,
                             groups)
 
-        if api.finish_transaction(trans, retval):
+        if store.confirm(retval):
             # FIXME: Storm is not expiring the groups correctly.
             # Figure out why. See bug 5087
             self.search.refresh()
             self._update_widgets()
-        trans.close()
+        store.close()
 
     def on_Edit__activate(self, action):
         try:
-            Till.get_current(self.conn)
+            Till.get_current(self.store)
         except TillError, e:
             warning(str(e))
             return
 
-        trans = api.new_transaction()
+        store = api.new_store()
         views = self.results.get_selected_rows()
-        sale = trans.get(views[0].sale)
-        retval = run_dialog(SalePaymentsEditor, self, trans, sale)
+        sale = store.fetch(views[0].sale)
+        retval = run_dialog(SalePaymentsEditor, self, store, sale)
 
-        if api.finish_transaction(trans, retval):
+        if store.confirm(retval):
             self.search.refresh()
-        trans.close()
+        store.close()
 
     def on_PrintDocument__activate(self, action):
         view = self.results.get_selected_rows()[0]
