@@ -30,7 +30,6 @@ from kiwi.ui.widgets.label import ProxyLabel
 from stoqlib.lib.interfaces import IAppInfo
 from stoqlib.lib.settings import get_settings
 
-from stoq.main import get_shell
 from stoq.gui.shell.bootstrap import ShellBootstrap
 
 
@@ -79,10 +78,6 @@ class TestMain(unittest.TestCase):
             # Those two fail as testsuit already setup them
             '_setup_gobject',
             '_setup_twisted',
-            # Do not setup database, as it may want to do a migration,
-            # activate plugins, check db version, etc.
-            # We may want to test this in the future
-            '_setup_database',
             ]:
             mocked = mock.patch.object(bootstrap, func, new=lambda: None)
             mocks.append(mocked)
