@@ -32,7 +32,6 @@ from kiwi.currency import currency
 from kiwi.datatypes import converter
 from kiwi.log import Logger
 from kiwi.enums import SearchFilterPosition
-from kiwi.python import Settable
 from kiwi.ui.search import ComboSearchFilter
 from kiwi.ui.objectlist import Column, SearchColumn
 from storm.expr import And, Or
@@ -63,7 +62,7 @@ from stoqlib.reporting.sale import SalesReport
 
 from stoq.gui.application import SearchableAppWindow
 
-log = Logger('stoq.till')
+log = Logger(__name__)
 
 LOGO_WIDTH = 91
 LOGO_HEIGHT = 32
@@ -260,27 +259,7 @@ class TillApp(SearchableAppWindow):
             store.close()
             return
 
-        # Lets confirm that we can create the sale, before opening the coupon
-        prod_sold = dict()
-        prod_desc = dict()
-        for sale_item in sale.get_items():
-            # Skip services, since we don't need stock to sell.
-            if sale_item.is_service():
-                continue
-            storable = sale_item.sellable.product_storable
-            prod_sold.setdefault(storable, 0)
-            prod_sold[storable] += sale_item.quantity
-            prod_desc[storable] = sale_item.sellable.get_description()
-
-        branch = self.current_branch
-        missing = []
-        for storable in prod_sold.keys():
-            stock = storable.get_balance_for_branch(branch)
-            if stock < prod_sold[storable]:
-                missing.append(Settable(storable=storable,
-                                        description=prod_desc[storable],
-                                        ordered=prod_sold[storable],
-                                        stock=stock))
+        missing = sale.get_missing_items()
 
         if missing:
             retval = run_dialog(ConfirmSaleMissingDialog, self, sale, missing)
