@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2005-2009 Async Open Source
+## Copyright (C) 2005-2012 Async Open Source
 ##
 ## This program is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU Lesser General Public License
@@ -22,21 +22,3 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 ##
-
-import os
-import sys
-
-from kiwi.environ import Library
-
-__all__ = ['library']
-
-library = Library('stoq', root='..')
-if library.uninstalled:
-    library.add_resource('plugin', 'plugins')
-    externals = os.path.join(library.get_root(), 'external')
-else:
-    # root = $prefix/lib/pythonX.Y/site-packages
-    # We want $prefix/lib/stoqlib, eg ../../stoqlib
-    externals = os.path.join(library.prefix, 'lib', 'stoqlib')
-sys.path.insert(0, externals)
-library.enable_translation(domain="stoq")
