@@ -51,14 +51,15 @@ from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.net.socketutils import get_hostname
 
 _ = stoqlib_gettext
-log = Logger('stoqlib.runtime')
+log = Logger(__name__)
 
 #: the default store, considered read-only in Stoq
 _default_store = None
 
+# FIXME: Use weakref.WeakSet when we can depend on Python 2.7
 #: list of global stores used by the application,
 #: should not be used by anything except autoreload_object()
-_stores = weakref.WeakSet()
+_stores = weakref.WeakKeyDictionary()
 
 
 def autoreload_object(obj):
@@ -189,7 +190,8 @@ class StoqlibStore(Store):
         if database is None:
             database = get_default_store().get_database()
         Store.__init__(self, database=database, cache=cache)
-        _stores.add(self)
+        # FIXME: Use weakref.WeakSet when we can depend on Python 2.7
+        _stores[self] = None
         trace('transaction_create', self)
         self._reset_pending_objs()
 
@@ -492,9 +494,16 @@ class StoqlibStore(Store):
                 processed_objs.add(created_obj)
 
             for modified_obj in modified_objs:
-                modified_obj.te.te_time = te_time
-                modified_obj.te.station_id = station_id
-                modified_obj.te.user_id = user_id
+                # This is to support migration from domainv1
+                if hasattr(modified_obj, 'te_modified'):
+                    modified_obj.te_modified.te_time = te_time
+                    modified_obj.te_modified.station_id = station_id
+                    modified_obj.te_modified.user_id = user_id
+                # And also from domainv2
+                else:
+                    modified_obj.te.te_time = te_time
+                    modified_obj.te.station_id = station_id
+                    modified_obj.te.user_id = user_id
 
                 modified_obj.on_update()
                 processed_objs.add(modified_obj)
@@ -618,6 +627,7 @@ def set_current_branch_station(store, station_name):
         if station_name is None:
             station_name = get_hostname()
 
+    station_name = unicode(station_name)
     from stoqlib.domain.station import BranchStation
     station = store.find(BranchStation, name=station_name).one()
     if station is None:
