@@ -38,7 +38,7 @@ from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
-log = Logger('stoqlib.database.tables')
+log = Logger(__name__)
 
 
 _tables = [
@@ -136,6 +136,9 @@ _tables = [
      ('costcenter', ['CostCenter', 'CostCenterEntry']),
      ('stockdecrease', ['StockDecrease',
                         'StockDecreaseItem']),
+     ('workorder', ['WorkOrder',
+                    'WorkOrderItem',
+                    'WorkOrderCategory']),
      ('event', ['Event']),
 ]
 
