@@ -25,13 +25,13 @@
 
 import unittest
 
-from stoqlib.database.runtime import finish_transaction, new_transaction
+from stoqlib.database.runtime import new_store
 from stoqlib.domain.person import Person
 
 from storm.exceptions import ClosedError
 
 
-class FakeTransaction:
+class FakeStore:
     def __init__(self):
         self.committed = False
         self.rollbacked = False
@@ -42,6 +42,13 @@ class FakeTransaction:
     def rollback(self, close):
         self.rollbacked = True
 
+    def confirm(self, commit):
+        if commit:
+            self.commit()
+        else:
+            self.rollback(False)
+        return commit
+
 
 class Model:
     pass
@@ -50,26 +57,25 @@ class Model:
 class DatabaseTest(unittest.TestCase):
     def testFinishTransaction(self):
         for item in (True, object(), Model()):
-            trans = FakeTransaction()
-            finish_transaction(trans, item)
+            trans = FakeStore()
+            trans.confirm(item)
             self.failUnless(trans.committed, "%s is not committed" % item)
             self.failIf(trans.rollbacked, "%s is rollbacked" % item)
 
         for item in (False, None):
-            trans = FakeTransaction()
-            finish_transaction(trans, item)
+            trans = FakeStore()
+            trans.confirm(item)
             self.failIf(trans.committed, "%s is committed" % item)
             self.failUnless(trans.rollbacked, "%s is not rollbacked" % item)
 
     def testRollback(self):
-        trans = new_transaction()
-        Person.selectOneBy(id=1, connection=trans)
+        trans = new_store()
+        trans.find(Person, id=1).one()
 
         trans.rollback(close=False)
         # Should be ok to use trans again
-        Person.selectOneBy(id=1, connection=trans)
+        trans.find(Person, id=1).one()
 
         trans.rollback(close=True)
         # Should not be ok to use trans again
-        self.assertRaises(ClosedError, Person.selectOneBy, id=1,
-                          connection=trans)
+        self.assertRaises(ClosedError, trans.find(Person, id=1).one)
