@@ -35,6 +35,7 @@ Starting point for the domain classes:
 * :py:mod:`stoqlib.domain.account`: bank accounts and transactions
 * :py:mod:`stoqlib.domain.address`: address
 * :py:mod:`stoqlib.domain.base`: base infrastructure
+* :py:mod:`stoqlib.domain.costcenter`: cost centers
 * :py:mod:`stoqlib.domain.commission`: sale commission
 * :py:mod:`stoqlib.domain.devices`: device drivers
 * :py:mod:`stoqlib.domain.event`: persistent database logging
@@ -47,6 +48,7 @@ Starting point for the domain classes:
 * :py:mod:`stoqlib.domain.invoice`: invoices and fields
 * :py:mod:`stoqlib.domain.loan`: loads
 * :py:mod:`stoqlib.domain.parameter`: configuration parameters
+* :py:mod:`stoqlib.domain.payment.card`: card payment method related domain
 * :py:mod:`stoqlib.domain.payment.category`: user categorization
 * :py:mod:`stoqlib.domain.payment.comment`: annotations
 * :py:mod:`stoqlib.domain.payment.group`: group/set of payments
