@@ -27,15 +27,17 @@ Commission management
 
 from decimal import Decimal
 
-from stoqlib.database.orm import PercentCol, PriceCol
-from stoqlib.database.orm import ForeignKey, IntCol
-from stoqlib.database.orm import Join
-from stoqlib.database.orm import Viewable
+from storm.expr import Join
+from storm.references import Reference
+
+from stoqlib.database.properties import PercentCol, PriceCol
+from stoqlib.database.properties import IntCol
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.person import Person, SalesPerson
 from stoqlib.domain.sale import Sale
-
+from stoqlib.lib.defaults import quantize
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -58,17 +60,23 @@ class CommissionSource(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/commission_source.html>`__,
     """
 
+    __storm_table__ = 'commission_source'
+
     #: the commission value to be used in a |sale| with one installment
     direct_value = PercentCol()
 
     #: the commission value to be used in a |sale| with multiple installments
     installments_value = PercentCol()
 
+    category_id = IntCol(default=None)
+
     #: the |sellablecategory|
-    category = ForeignKey('SellableCategory', default=None)
+    category = Reference(category_id, 'SellableCategory.id')
+
+    sellable_id = IntCol(default=None)
 
     #: the |sellable|
-    sellable = ForeignKey('Sellable', default=None)
+    sellable = Reference(sellable_id, 'Sellable.id')
 
 
 class Commission(Domain):
@@ -83,6 +91,8 @@ class Commission(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/commission.html>`__,
     """
 
+    __storm_table__ = 'commission'
+
     #: use direct commission to calculate the commission amount
     DIRECT = 0
 
@@ -94,22 +104,28 @@ class Commission(Domain):
     #: The commission amount
     value = PriceCol(default=0)
 
+    salesperson_id = IntCol()
+
     #: who sold the |sale| this commission applies to
-    salesperson = ForeignKey('SalesPerson')
+    salesperson = Reference(salesperson_id, 'SalesPerson.id')
+
+    sale_id = IntCol()
 
     #: the |sale| this commission applies to
-    sale = ForeignKey('Sale')
+    sale = Reference(sale_id, 'Sale.id')
+
+    payment_id = IntCol()
 
     #: the |payment| this commission applies to
-    payment = ForeignKey('Payment')
+    payment = Reference(payment_id, 'Payment.id')
 
     #
     #  Domain
     #
 
-    def _create(self, id, **kwargs):
+    def __init__(self, store=None, **kwargs):
         need_calculate_value = not 'value' in kwargs
-        super(Commission, self)._create(id, **kwargs)
+        super(Commission, self).__init__(store=store, **kwargs)
         if need_calculate_value:
             self._calculate_value()
 
@@ -131,13 +147,15 @@ class Commission(Domain):
         #   which was bought in the sale. Then the commission received by the
         #   sales person is also going to be 20% and 80% of the complete
         #   commission amount for the sale when that specific payment is payed.
-        value = 0
+        value = Decimal(0)
         for sellable_item in self.sale.get_items():
             value += (self._get_commission(sellable_item.sellable) *
                       sellable_item.get_total() *
                       relative_percentage)
 
-        self.value = value
+        # The calculation above may have produced a number with more than two
+        # digits. Round it to only two
+        self.value = quantize(value)
 
     def _get_payment_percentage(self):
         """Return the payment percentage of sale"""
@@ -152,9 +170,8 @@ class Commission(Domain):
         calculate the commission amount, for a given sellable.
         """
 
-        conn = self.get_connection()
-        source = CommissionSource.selectOneBy(sellable=sellable,
-                                              connection=conn)
+        store = self.store
+        source = store.find(CommissionSource, sellable=sellable).one()
         if not source and sellable.category:
             source = self._get_category_commission(sellable.category)
 
@@ -170,9 +187,8 @@ class Commission(Domain):
 
     def _get_category_commission(self, category):
         if category:
-            source = CommissionSource.selectOneBy(
-                category=category,
-                connection=self.get_connection())
+            store = self.store
+            source = store.find(CommissionSource, category=category).one()
             if not source:
                 return self._get_category_commission(category.category)
             return source
@@ -187,43 +203,33 @@ class CommissionView(Viewable):
         sale and payment.
     """
 
-    columns = dict(
-        id=Sale.q.id,
-        identifier=Sale.q.identifier,
-        sale_status=Sale.q.status,
-        code=Commission.q.id,
-        commission_value=Commission.q.value,
-        commission_percentage=Commission.q.value / Payment.q.value * 100,
-        salesperson_name=Person.q.name,
-        payment_id=Payment.q.id,
-        payment_value=Payment.q.value,
-        open_date=Sale.q.open_date,
-       )
+    id = Sale.id
+    identifier = Sale.identifier
+    sale_status = Sale.status
+    code = Commission.id
+    commission_value = Commission.value
+    commission_percentage = Commission.value / Payment.value * 100
+    salesperson_name = Person.name
+    payment_id = Payment.id
+    payment_value = Payment.value
+    confirm_date = Sale.confirm_date
+    paid_date = Payment.paid_date
 
-    joins = [
-        # commission
-        Join(Commission,
-            Commission.q.sale_id == Sale.q.id),
-
-        # person
-        Join(SalesPerson,
-            SalesPerson.q.id == Commission.q.salesperson_id),
-
-        Join(Person,
-            Person.q.id == SalesPerson.q.person_id),
-
-        # payment
-        Join(Payment,
-            Payment.q.id == Commission.q.payment_id),
+    tables = [
+        Sale,
+        Join(Commission, Commission.sale_id == Sale.id),
+        Join(SalesPerson, SalesPerson.id == Commission.salesperson_id),
+        Join(Person, Person.id == SalesPerson.person_id),
+        Join(Payment, Payment.id == Commission.payment_id),
        ]
 
     @property
     def sale(self):
-        return Sale.get(self.id, connection=self.get_connection())
+        return self.store.get(Sale, self.id)
 
     @property
     def payment(self):
-        return Payment.get(self.payment_id, connection=self.get_connection())
+        return self.store.get(Payment, self.payment_id)
 
     def quantity_sold(self):
         if self.sale_returned():
