@@ -29,12 +29,11 @@ from zope.interface import implements
 from stoqdrivers.printers.cheque import ChequePrinter
 from stoqdrivers.scales.scales import Scale
 from stoqdrivers.serialbase import SerialPort
+from storm.references import Reference, ReferenceSet
 
-from stoqlib.database.orm import PriceCol
-from stoqlib.database.orm import (UnicodeCol, IntCol, ForeignKey, BoolCol,
-                           DateTimeCol, StringCol)
-from stoqlib.database.orm import MultipleJoin
-from stoqlib.database.orm import AND
+from stoqlib.database.properties import PriceCol
+from stoqlib.database.properties import (IntCol, BoolCol,
+                                         DateTimeCol, UnicodeCol)
 from stoqlib.database.runtime import get_current_station
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IActive, IDescribable
@@ -47,26 +46,29 @@ _ = stoqlib_gettext
 class DeviceSettings(Domain):
     implements(IActive, IDescribable)
 
+    __storm_table__ = 'device_settings'
+
     type = IntCol()
     brand = UnicodeCol()
     model = UnicodeCol()
     device_name = UnicodeCol()
-    station = ForeignKey("BranchStation")
+    station_id = IntCol()
+    station = Reference(station_id, 'BranchStation.id')
     is_active = BoolCol(default=True)
 
     (SCALE_DEVICE,
      _UNUSED,
      CHEQUE_PRINTER_DEVICE) = range(1, 4)
 
-    device_types = {SCALE_DEVICE: _('Scale'),
-                    CHEQUE_PRINTER_DEVICE: _('Cheque Printer')}
+    device_types = {SCALE_DEVICE: _(u'Scale'),
+                    CHEQUE_PRINTER_DEVICE: _(u'Cheque Printer')}
 
     #
     # Domain
     #
 
     def get_printer_description(self):
-        return "%s %s" % (self.brand.capitalize(), self.model)
+        return u"%s %s" % (self.brand.capitalize(), self.model)
 
     def get_device_type_name(self, type=None):
         return DeviceSettings.device_types[type or self.type]
@@ -95,30 +97,25 @@ class DeviceSettings(Domain):
                 and self.type in DeviceSettings.device_types)
 
     @classmethod
-    def get_by_station_and_type(cls, conn, station, type):
+    def get_by_station_and_type(cls, store, station, type):
         """Fetch all settings for a specific station and type.
 
-        :param conn: a database connection
+        :param store: a store
         :param station: a BranchStation instance
         :param type: device type
         """
-        return cls.select(
-            AND(cls.q.station_id == station,
-                cls.q.type == type),
-        connection=conn)
+        return store.find(cls, station=station, type=type)
 
     @classmethod
-    def get_scale_settings(cls, conn):
+    def get_scale_settings(cls, store):
         """
         Get the scale device settings for the current station
-        :param conn: a database connection
+        :param store: a store
         :returns: a :class:`DeviceSettings` object or None if there is none
         """
-        station = get_current_station(conn)
-        return cls.selectOneBy(
-            connection=conn,
-            station=station,
-            type=cls.SCALE_DEVICE)
+        station = get_current_station(store)
+        return store.find(cls, station=station,
+                          type=cls.SCALE_DEVICE).one()
 
     #
     # IActive implementation
@@ -147,7 +144,11 @@ class FiscalDayTax(Domain):
     """This represents the information that needs to be used to
     generate a Sintegra file of type 60M.
     """
-    fiscal_day_history = ForeignKey('FiscalDayHistory')
+
+    __storm_table__ = 'fiscal_day_tax'
+
+    fiscal_day_history_id = IntCol()
+    fiscal_day_history = Reference(fiscal_day_history_id, 'FiscalDayHistory.id')
 
     #: four bytes, either the percental of the tax, 1800 for 18% or one of:
     #:
@@ -157,19 +158,23 @@ class FiscalDayTax(Domain):
     #: * ``ISS``: ISS
     #: * ``CANC``: Cancelled
     #: * ``DESC``: Discount
-    code = StringCol()
+    code = UnicodeCol()
 
     value = PriceCol()
-    type = StringCol()
+    type = UnicodeCol()
 
 
 class FiscalDayHistory(Domain):
     """This represents the information that needs to be used to
     generate a Sintegra file of type 60A.
     """
+
+    __storm_table__ = 'fiscal_day_history'
+
     emission_date = DateTimeCol()
-    station = ForeignKey('BranchStation')
-    serial = StringCol()
+    station_id = IntCol()
+    station = Reference(station_id, 'BranchStation.id')
+    serial = UnicodeCol()
     serial_id = IntCol()
     coupon_start = IntCol()
     coupon_end = IntCol()
@@ -177,5 +182,5 @@ class FiscalDayHistory(Domain):
     crz = IntCol()
     period_total = PriceCol()
     total = PriceCol()
-    taxes = MultipleJoin('FiscalDayTax', 'fiscal_day_history_id')
+    taxes = ReferenceSet('id', 'FiscalDayTax.fiscal_day_history_id')
     reduction_date = DateTimeCol()
