@@ -262,6 +262,7 @@ class ExampleCreator(object):
             'UserProfile': self.create_user_profile,
             'VoterData': self.create_voter_data,
             'WorkPermitData': self.create_work_permit_data,
+            'WorkOrder': self.create_workorder,
             'ProductionOrder': self.create_production_order,
             'ProductionItem': self.create_production_item,
             'ProductionMaterial': self.create_production_material,
@@ -345,7 +346,9 @@ class ExampleCreator(object):
     def create_individual(self):
         from stoqlib.domain.person import Individual, Person
         person = Person(name=u'individual', store=self.store)
-        return Individual(person=person, store=self.store)
+        return Individual(person=person,
+                          birth_date=datetime.datetime(1970, 1, 1),
+                          store=self.store)
 
     def create_user(self, username=u'username'):
         from stoqlib.domain.person import LoginUser
@@ -827,6 +830,10 @@ class ExampleCreator(object):
         from stoqlib.domain.payment.group import PaymentGroup
         return PaymentGroup(store=self.store)
 
+    def create_payment_comment(self, comment):
+        from stoqlib.domain.payment.comment import PaymentComment
+        return PaymentComment(store=self.store, comment=comment)
+
     def create_sellable_tax_constant(self):
         from stoqdrivers.enum import TaxType
         from stoqlib.domain.sellable import SellableTaxConstant
@@ -871,6 +878,14 @@ class ExampleCreator(object):
                                  quantity=quantity,
                                  store=self.store)
 
+    def create_workorder(self, equipment=u''):
+        from stoqlib.domain.workorder import WorkOrder
+        return WorkOrder(
+            store=self.store,
+            equipment=equipment,
+            branch=get_current_branch(self.store),
+            )
+
     def create_inventory(self, branch=None):
         from stoqlib.domain.inventory import Inventory
         branch = branch or self.create_branch(u"Main")
