@@ -28,7 +28,7 @@ import base64
 
 from zope.interface import implements
 
-from stoqlib.database.orm import BLOBCol, UnicodeCol
+from stoqlib.database.properties import BLOBCol, UnicodeCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import (ImageCreateEvent, ImageEditEvent,
                                    ImageRemoveEvent)
@@ -41,13 +41,18 @@ _ = stoqlib_gettext
 class Image(Domain):
     """Class responsible for storing images and it's description
 
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/image.html>`__
+
     """
 
+    implements(IDescribable)
+
+    __storm_table__ = 'image'
+
     (THUMBNAIL_SIZE_HEIGHT,
      THUMBNAIL_SIZE_WIDTH) = (64, 64)
 
-    implements(IDescribable)
-
     #: the image itself in a bin format
     image = BLOBCol(default=None)
 
@@ -55,7 +60,7 @@ class Image(Domain):
     thumbnail = BLOBCol(default=None)
 
     #: the image description
-    description = UnicodeCol(default='')
+    description = UnicodeCol(default=u'')
 
     #
     #  Public API
@@ -71,16 +76,17 @@ class Image(Domain):
     def get_description(self):
         if self.description:
             return self.description
-        return _("Stoq image #%d" % (self.id,))
+        # TODO: Dont use id here
+        return _(u"Stoq image #%d") % (self.id,)
 
     #
     #  ORMObject
     #
 
     @classmethod
-    def delete(cls, id, conn):
-        ImageRemoveEvent.emit(cls.get(id, conn))
-        super(Image, cls).delete(id, conn)
+    def delete(cls, id, store):
+        ImageRemoveEvent.emit(cls.get(id, store))
+        super(Image, cls).delete(id, store)
 
     #
     # Domain
