@@ -34,8 +34,8 @@ from kiwi.component import get_utility, provide_utility
 from zope.interface import implements
 
 from stoqlib.domain.account import BankAccount
-from stoqlib.domain.payment.method import CheckData, CreditCardData, Payment
-from stoqlib.domain.person import CreditProvider
+from stoqlib.domain.payment.card import CreditProvider, CreditCardData
+from stoqlib.domain.payment.method import CheckData, Payment
 from stoqlib.lib.interfaces import IPaymentOperation, IPaymentOperationManager
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -47,7 +47,7 @@ _ = stoqlib_gettext
 class MoneyPaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Money')
+    description = _(u'Money')
     max_installments = 1
 
     #
@@ -94,25 +94,25 @@ class MoneyPaymentOperation(object):
 class CheckPaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Check')
+    description = _(u'Check')
     max_installments = 12
 
     def payment_create(self, payment):
-        conn = payment.get_connection()
-        bank_account = BankAccount(connection=conn,
+        store = payment.store
+        bank_account = BankAccount(store=store,
                                    bank_number=None,
-                                   bank_branch='',
-                                   bank_account='')
+                                   bank_branch=u'',
+                                   bank_account=u'')
         CheckData(bank_account=bank_account,
                   payment=payment,
-                  connection=conn)
+                  store=store)
 
     def payment_delete(self, payment):
-        conn = payment.get_connection()
+        store = payment.store
         check_data = self.get_check_data_by_payment(payment)
         bank_account = check_data.bank_account
-        CheckData.delete(check_data.id, connection=conn)
-        BankAccount.delete(bank_account.id, connection=conn)
+        store.remove(check_data)
+        store.remove(bank_account)
 
     def create_transaction(self):
         return True
@@ -151,14 +151,14 @@ class CheckPaymentOperation(object):
     @argcheck(Payment)
     def get_check_data_by_payment(self, payment):
         """Get an existing CheckData instance from a payment object."""
-        return CheckData.selectOneBy(payment=payment,
-                                     connection=payment.get_connection())
+        store = payment.store
+        return store.find(CheckData, payment=payment).one()
 
 
 class BillPaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Bill')
+    description = _(u'Bill')
     max_installments = 12
 
     #
@@ -215,7 +215,7 @@ class BillPaymentOperation(object):
 class CardPaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Card')
+    description = _(u'Card')
     max_installments = 12
 
     CARD_METHOD_CONSTANTS = {
@@ -233,20 +233,20 @@ class CardPaymentOperation(object):
     #
 
     def payment_create(self, payment):
-        return CreditCardData(connection=payment.get_connection(),
+        return CreditCardData(store=payment.store,
                               payment=payment)
 
     def payment_delete(self, payment):
-        conn = payment.get_connection()
+        store = payment.store
         credit_card_data = self.get_card_data_by_payment(payment)
-        CreditCardData.delete(credit_card_data.id, connection=conn)
+        CreditCardData.delete(credit_card_data.id, store=store)
 
     def create_transaction(self):
         return True
 
     def selectable(self, method):
         return CreditProvider.has_card_provider(
-            method.get_connection())
+            method.store)
 
     def creatable(self, method, payment_type, separate):
         # FIXME: this needs more work, probably just a simple bug
@@ -283,14 +283,14 @@ class CardPaymentOperation(object):
     @argcheck(Payment)
     def get_card_data_by_payment(self, payment):
         """Get an existing CreditCardData instance from a payment object."""
-        return CreditCardData.selectOneBy(payment=payment,
-                                          connection=payment.get_connection())
+        store = payment.store
+        return store.find(CreditCardData, payment=payment).one()
 
 
 class StoreCreditPaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Store Credit')
+    description = _(u'Store Credit')
     max_installments = 1
     #
     # IPaymentOperation
@@ -352,7 +352,7 @@ class StoreCreditPaymentOperation(object):
 class DepositPaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Deposit')
+    description = _(u'Deposit')
     max_installments = 12
 
     #
@@ -399,7 +399,7 @@ class DepositPaymentOperation(object):
 class OnlinePaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Online')
+    description = _(u'Online')
     max_installments = 1
 
     #
@@ -447,7 +447,7 @@ class OnlinePaymentOperation(object):
 class TradePaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Trade')
+    description = _(u'Trade')
     max_installments = 1
 
     #
@@ -499,7 +499,7 @@ class TradePaymentOperation(object):
 class MultiplePaymentOperation(object):
     implements(IPaymentOperation)
 
-    description = _('Multiple')
+    description = _(u'Multiple')
     max_installments = 12
 
     #
@@ -559,7 +559,7 @@ class InvalidPaymentOperation(object):
     """
     implements(IPaymentOperation)
 
-    description = _('Invalid payment')
+    description = _(u'Invalid payment')
     max_installments = 1
 
     #
@@ -613,15 +613,15 @@ def get_payment_operation_manager():
         provide_utility(IPaymentOperationManager, pmm)
 
         for method_name, klass in [
-            ('money', MoneyPaymentOperation),
-            ('check', CheckPaymentOperation),
-            ('bill', BillPaymentOperation),
-            ('card', CardPaymentOperation),
-            ('store_credit', StoreCreditPaymentOperation),
-            ('trade', TradePaymentOperation),
-            ('multiple', MultiplePaymentOperation),
-            ('deposit', DepositPaymentOperation),
-            ('online', OnlinePaymentOperation),
+            (u'money', MoneyPaymentOperation),
+            (u'check', CheckPaymentOperation),
+            (u'bill', BillPaymentOperation),
+            (u'card', CardPaymentOperation),
+            (u'store_credit', StoreCreditPaymentOperation),
+            (u'trade', TradePaymentOperation),
+            (u'multiple', MultiplePaymentOperation),
+            (u'deposit', DepositPaymentOperation),
+            (u'online', OnlinePaymentOperation),
             ]:
             pmm.register(method_name, klass())
         # Also, register InvalidPaymentOperation as a fallback operation
@@ -638,7 +638,7 @@ def get_payment_operation(method_name):
     pmm = get_payment_operation_manager()
     pm = pmm.get(method_name)
     if not pm:
-        raise KeyError("There's no payment operation for method '%s'" %
+        raise KeyError(u"There's no payment operation for method '%s'" %
                        method_name)
 
     return pm
