@@ -24,13 +24,15 @@
 """ Domain classes for renegotiation management """
 
 import datetime
-from zope.interface import implements
 
 from kiwi.currency import currency
+from storm.references import Reference
+from storm.store import AutoReload
+from zope.interface import implements
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import PriceCol, const
-from stoqlib.database.orm import ForeignKey, UnicodeCol, IntCol, DateTimeCol
+from stoqlib.database.expr import TransactionTimestamp
+from stoqlib.database.properties import (PriceCol, UnicodeCol,
+                                  IntCol, DateTimeCol)
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.domain.payment.payment import Payment
@@ -49,6 +51,8 @@ class PaymentRenegotiation(Domain):
     """
     implements(IContainer)
 
+    __storm_table__ = 'payment_renegotiation'
+
     (STATUS_CONFIRMED,
      STATUS_PAID,
      STATUS_RENEGOTIATED) = range(3)
@@ -69,10 +73,14 @@ class PaymentRenegotiation(Domain):
     discount_value = PriceCol(default=0)
     surcharge_value = PriceCol(default=0)
     total = PriceCol(default=0)
-    responsible = ForeignKey('LoginUser')
-    client = ForeignKey('Client', default=None)
-    branch = ForeignKey('Branch', default=None)
-    group = ForeignKey('PaymentGroup')
+    responsible_id = IntCol()
+    responsible = Reference(responsible_id, 'LoginUser.id')
+    client_id = IntCol(default=None)
+    client = Reference(client_id, 'Client.id')
+    branch_id = IntCol(default=None)
+    branch = Reference(branch_id, 'Branch.id')
+    group_id = IntCol()
+    group = Reference(group_id, 'PaymentGroup.id')
 
     #
     # Public API
@@ -108,7 +116,7 @@ class PaymentRenegotiation(Domain):
         renegotiated and the operations will be done in other payment group."""
         assert self.can_set_renegotiated()
 
-        self.close_date = const.NOW()
+        self.close_date = TransactionTimestamp()
         self.status = PaymentRenegotiation.STATUS_RENEGOTIATED
 
     @property
@@ -128,5 +136,4 @@ class PaymentRenegotiation(Domain):
         pass
 
     def get_items(self):
-        return PaymentGroup.selectBy(renegotiation=self,
-                                     connection=self.get_connection())
+        return self.store.find(PaymentGroup, renegotiation=self)
