@@ -28,15 +28,16 @@ from decimal import Decimal
 
 from kiwi.argcheck import argcheck
 from kiwi.currency import currency
+from storm.references import Reference
+from storm.store import AutoReload
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import PriceCol, QuantityCol
-from stoqlib.database.orm import ForeignKey, IntCol, DateTimeCol, UnicodeCol
+from stoqlib.database.properties import PriceCol, QuantityCol
+from stoqlib.database.properties import IntCol, DateTimeCol, UnicodeCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.fiscal import FiscalBookEntry
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.product import ProductHistory
+from stoqlib.domain.product import ProductHistory, StockTransactionHistory
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.parameters import sysparam
@@ -48,18 +49,27 @@ _ = stoqlib_gettext
 class ReceivingOrderItem(Domain):
     """This class stores information of the purchased items.
     """
+
+    __storm_table__ = 'receiving_order_item'
+
     #: the total quantity received for a certain |product|
     quantity = QuantityCol()
 
     #: the cost for each |product| received
     cost = PriceCol()
 
-    purchase_item = ForeignKey('PurchaseItem')
+    purchase_item_id = IntCol()
+
+    purchase_item = Reference(purchase_item_id, 'PurchaseItem.id')
+
+    sellable_id = IntCol()
 
     #: the |sellable|
-    sellable = ForeignKey('Sellable')
+    sellable = Reference(sellable_id, 'Sellable.id')
 
-    receiving_order = ForeignKey('ReceivingOrder')
+    receiving_order_id = IntCol()
+
+    receiving_order = Reference(receiving_order_id, 'ReceivingOrder.id')
 
     #
     # Accessors
@@ -80,38 +90,42 @@ class ReceivingOrderItem(Domain):
 
     def get_quantity_unit_string(self):
         unit = self.sellable.unit
-        return "%s %s" % (self.quantity,
+        return u"%s %s" % (self.quantity,
                           unit and unit.description or u"")
 
     def get_unit_description(self):
         unit = self.sellable.unit
-        return "%s" % (unit and unit.description or "")
+        return u"%s" % (unit and unit.description or u"")
 
     def add_stock_items(self):
         """This is normally called from ReceivingOrder when
         a the receving order is confirmed.
         """
-        conn = self.get_connection()
+        store = self.store
         if self.quantity > self.get_remaining_quantity():
             raise ValueError(
-                "Quantity received (%d) is greater than "
-                "quantity ordered (%d)" % (
+                u"Quantity received (%d) is greater than "
+                u"quantity ordered (%d)" % (
                 self.quantity,
                 self.get_remaining_quantity()))
 
         branch = self.receiving_order.branch
         storable = self.sellable.product_storable
-        if storable is not None:
-            storable.increase_stock(self.quantity, branch, self.cost)
         purchase = self.purchase_item.order
+        if storable is not None:
+            storable.increase_stock(self.quantity, branch,
+                                    StockTransactionHistory.TYPE_RECEIVED_PURCHASE,
+                                    self.id, self.cost)
         purchase.increase_quantity_received(self.purchase_item, self.quantity)
-        ProductHistory.add_received_item(conn, branch, self)
+        ProductHistory.add_received_item(store, branch, self)
 
 
 class ReceivingOrder(Domain):
     """Receiving order definition.
     """
 
+    __storm_table__ = 'receiving_order'
+
     #: Products in the order was not received or received partially.
     STATUS_PENDING = 0
 
@@ -124,12 +138,12 @@ class ReceivingOrder(Domain):
      FREIGHT_CIF_INVOICE) = range(4)
 
     freight_types = {FREIGHT_FOB_PAYMENT: _(u"FOB - Freight value "
-                                            "on a new payment"),
+                                            u"on a new payment"),
                      FREIGHT_FOB_INSTALLMENTS: _(u"FOB - Freight value "
-                                                 "on installments"),
+                                                 u"on installments"),
                      FREIGHT_CIF_UNKNOWN: _(u"CIF - Freight value is unknown"),
                      FREIGHT_CIF_INVOICE: _(u"CIF - Freight value highlighted "
-                                            "on invoice")}
+                                            u"on invoice")}
 
     FOB_FREIGHTS = (FREIGHT_FOB_PAYMENT,
                     FREIGHT_FOB_INSTALLMENTS, )
@@ -151,7 +165,7 @@ class ReceivingOrder(Domain):
     confirm_date = DateTimeCol(default=None)
 
     #: Some optional additional information related to this order.
-    notes = UnicodeCol(default='')
+    notes = UnicodeCol(default=u'')
 
     #: Type of freight
     freight_type = IntCol(default=FREIGHT_FOB_PAYMENT)
@@ -177,28 +191,36 @@ class ReceivingOrder(Domain):
     #: The number of the order that has been received.
     invoice_number = IntCol()
     invoice_total = PriceCol(default=None)
-    cfop = ForeignKey("CfopData")
+    cfop_id = IntCol()
+    cfop = Reference(cfop_id, 'CfopData.id')
 
-    responsible = ForeignKey('LoginUser')
-    supplier = ForeignKey('Supplier')
-    branch = ForeignKey('Branch')
-    purchase = ForeignKey('PurchaseOrder')
-    transporter = ForeignKey('Transporter', default=None)
+    responsible_id = IntCol()
+    responsible = Reference(responsible_id, 'LoginUser.id')
+    supplier_id = IntCol()
+    supplier = Reference(supplier_id, 'Supplier.id')
+    branch_id = IntCol()
+    branch = Reference(branch_id, 'Branch.id')
+    purchase_id = IntCol()
+    purchase = Reference(purchase_id, 'PurchaseOrder.id')
+    transporter_id = IntCol(default=None)
+    transporter = Reference(transporter_id, 'Transporter.id')
 
-    def _create(self, id, **kw):
-        conn = self.get_connection()
+    def __init__(self, store=None, **kw):
+        Domain.__init__(self, store=store, **kw)
+        # These miss default parameters and needs to be set before
+        # cfop, which triggers an implicit flush.
+        self.branch = kw.pop('branch', None)
+        self.purchase = kw.pop('purchase', None)
+        self.supplier = kw.pop('supplier', None)
         if not 'cfop' in kw:
-            conn.block_implicit_flushes()
-            kw['cfop'] = sysparam(conn).DEFAULT_RECEIVING_CFOP
-            conn.unblock_implicit_flushes()
-        Domain._create(self, id, **kw)
+            self.cfop = sysparam(store).DEFAULT_RECEIVING_CFOP
 
     def confirm(self):
         for item in self.get_items():
             item.add_stock_items()
 
         FiscalBookEntry.create_product_entry(
-            self.get_connection(),
+            self.store,
             self.purchase.group, self.cfop, self.invoice_number,
             self.icms_total, self.ipi_total)
         self.invoice_total = self.get_total()
@@ -232,12 +254,12 @@ class ReceivingOrder(Domain):
             self._create_freight_payment()
 
     def _create_freight_payment(self):
-        conn = self.get_connection()
-        money_method = PaymentMethod.get_by_name(conn, 'money')
+        store = self.store
+        money_method = PaymentMethod.get_by_name(store, u'money')
         # If we have a transporter, the freight payment will be for him
         # (and in another payment group).
         if self.transporter is not None:
-            group = PaymentGroup(connection=conn)
+            group = PaymentGroup(store=store)
             group.recipient = self.transporter.person
         else:
             group = self.purchase.group
@@ -252,9 +274,8 @@ class ReceivingOrder(Domain):
         return payment
 
     def get_items(self):
-        conn = self.get_connection()
-        return ReceivingOrderItem.selectBy(receiving_order=self,
-                                           connection=conn)
+        store = self.store
+        return store.find(ReceivingOrderItem, receiving_order=self)
 
     def remove_items(self):
         for item in self.get_items():
@@ -262,7 +283,7 @@ class ReceivingOrder(Domain):
 
     def remove_item(self, item):
         assert item.receiving_order == self
-        type(item).delete(item.id, connection=self.get_connection())
+        type(item).delete(item.id, store=self.store)
 
     #
     # Properties
@@ -398,8 +419,8 @@ class ReceivingOrder(Domain):
         if not discount_value:
             return currency(0)
         subtotal = self.get_products_total()
-        assert subtotal > 0, ('the subtotal should not be zero '
-                              'at this point')
+        assert subtotal > 0, (u'the subtotal should not be zero '
+                              u'at this point')
         total = subtotal - discount_value
         percentage = (1 - total / subtotal) * 100
         return quantize(percentage)
@@ -420,8 +441,8 @@ class ReceivingOrder(Domain):
         if not surcharge_value:
             return currency(0)
         subtotal = self.get_products_total()
-        assert subtotal > 0, ('the subtotal should not be zero '
-                              'at this point')
+        assert subtotal > 0, (u'the subtotal should not be zero '
+                              u'at this point')
         total = subtotal + surcharge_value
         percentage = ((total / subtotal) - 1) * 100
         return quantize(percentage)
@@ -440,8 +461,8 @@ def get_receiving_items_by_purchase_order(purchase_order, receiving_order):
     :param receiving_order: a ReceivingOrder instance tied with the
                             receiving_items that will be created
     """
-    conn = purchase_order.get_connection()
-    return [ReceivingOrderItem(connection=conn,
+    store = purchase_order.store
+    return [ReceivingOrderItem(store=store,
                                quantity=item.get_pending_quantity(),
                                cost=item.cost,
                                sellable=item.sellable,
