@@ -118,6 +118,8 @@ class ReturnedSaleItem(Domain):
             storable.increase_stock(self.quantity, branch,
                                     StockTransactionHistory.TYPE_RETURNED_SALE,
                                     self.id)
+            if self.sale_item:
+                self.sale_item.quantity_decreased -= self.quantity
 
 
 class ReturnedSale(Domain):
