@@ -25,8 +25,11 @@
 import datetime
 from decimal import Decimal
 
-from stoqlib.database.orm import (IntCol, UnicodeCol, QuantityCol, DateTimeCol,
-                                  PriceCol, ForeignKey, BoolCol, PercentCol)
+from storm.info import get_cls_info
+from storm.references import Reference
+
+from stoqlib.database.properties import (UnicodeCol, QuantityCol, DateTimeCol,
+                                  PriceCol, IntCol, BoolCol, PercentCol)
 from stoqlib.domain.base import Domain
 
 # SIGLAS:
@@ -46,17 +49,8 @@ class BaseTax(Domain):
         if not template:
             return
 
-        for column in template.sqlmeta.columnList:
-            if column.name in [
-                'product_tax_template_id',
-                'te_created_id',
-                'te_modified_id',
-                'id',
-                # FIXME: SQLObject only, remove post storm migration
-                'te_created_id',
-                'te_modified_id',
-                'product_tax_template_id',
-                ]:
+        for column in get_cls_info(template.__class__).columns:
+            if column.name in ['product_tax_template_id', 'te_id', 'id']:
                 continue
 
             value = getattr(template, column.name)
@@ -78,6 +72,9 @@ class BaseICMS(BaseTax):
     creating NfeItemIcms objects
     """
 
+    # FIXME: this is only used by pylint
+    __storm_table__ = 'invalid'
+
     orig = IntCol(default=None)
     cst = IntCol(default=None)
 
@@ -102,11 +99,11 @@ class BaseIPI(BaseTax):
     (CALC_ALIQUOTA,
      CALC_UNIDADE) = range(2)
 
-    cl_enq = UnicodeCol(default='')
-    cnpj_prod = UnicodeCol(default='')
-    c_selo = UnicodeCol(default='')
+    cl_enq = UnicodeCol(default=u'')
+    cnpj_prod = UnicodeCol(default=u'')
+    c_selo = UnicodeCol(default=u'')
     q_selo = IntCol(default=None)
-    c_enq = UnicodeCol(default='')
+    c_enq = UnicodeCol(default=u'')
 
     cst = IntCol(default=None)
     p_ipi = PercentCol(default=None)
@@ -122,7 +119,10 @@ class BaseIPI(BaseTax):
 
 
 class ProductIcmsTemplate(BaseICMS):
-    product_tax_template = ForeignKey('ProductTaxTemplate')
+    __storm_table__ = 'product_icms_template'
+
+    product_tax_template_id = IntCol()
+    product_tax_template = Reference(product_tax_template_id, 'ProductTaxTemplate.id')
 
     # Simples Nacional
     p_cred_sn_valid_until = DateTimeCol(default=None)
@@ -140,32 +140,37 @@ class ProductIcmsTemplate(BaseICMS):
 
 
 class ProductIpiTemplate(BaseIPI):
-    product_tax_template = ForeignKey('ProductTaxTemplate')
+    __storm_table__ = 'product_ipi_template'
+    product_tax_template_id = IntCol()
+    product_tax_template = Reference(product_tax_template_id, 'ProductTaxTemplate.id')
 
 
 class ProductTaxTemplate(Domain):
     (TYPE_ICMS,
      TYPE_IPI) = range(2)
 
+    __storm_table__ = 'product_tax_template'
+
     types = {TYPE_ICMS: u"ICMS",
              TYPE_IPI: u"IPI"}
 
     type_map = {TYPE_ICMS: ProductIcmsTemplate,
                 TYPE_IPI: ProductIpiTemplate}
 
-    name = UnicodeCol(default='')
+    name = UnicodeCol(default=u'')
     tax_type = IntCol()
 
     def get_tax_model(self):
         klass = self.type_map[self.tax_type]
-        return klass.selectOneBy(product_tax_template=self,
-                                 connection=self.get_connection())
+        store = self.store
+        return store.find(klass, product_tax_template=self).one()
 
     def get_tax_type_str(self):
         return self.types[self.tax_type]
 
 
 class SaleItemIcms(BaseICMS):
+    __storm_table__ = 'sale_item_icms'
     v_bc = PriceCol(default=None)
     v_icms = PriceCol(default=None)
 
@@ -259,8 +264,8 @@ class SaleItemIcms(BaseICMS):
 
     def update_values(self):
         from stoqlib.domain.sale import SaleItem
-        sale_item = SaleItem.selectOneBy(icms_info=self,
-                                         connection=self.get_connection())
+        store = self.store
+        sale_item = store.find(SaleItem, icms_info=self).one()
         branch = sale_item.sale.branch
 
         # Simples nacional
@@ -271,22 +276,23 @@ class SaleItemIcms(BaseICMS):
 
 
 class SaleItemIpi(BaseIPI):
+    __storm_table__ = 'sale_item_ipi'
     v_ipi = PriceCol(default=0)
     v_bc = PriceCol(default=None)
     v_unid = PriceCol(default=None)
 
     def set_initial_values(self):
         from stoqlib.domain.sale import SaleItem
-        sale_item = SaleItem.selectOneBy(ipi_info=self,
-                                         connection=self.get_connection())
+        store = self.store
+        sale_item = store.find(SaleItem, ipi_info=self).one()
         self.q_unid = sale_item.quantity
         self.v_unid = sale_item.price
         self.update_values()
 
     def update_values(self):
         from stoqlib.domain.sale import SaleItem
-        sale_item = SaleItem.selectOneBy(ipi_info=self,
-                                         connection=self.get_connection())
+        store = self.store
+        sale_item = store.find(SaleItem, ipi_info=self).one()
 
         # IPI is only calculated if cst is one of the following
         if not self.cst in (0, 49, 50, 99):
