@@ -39,6 +39,7 @@ from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.sale import Sale, SalePaymentMethodView
 from stoqlib.domain.till import TillEntry
 from stoqlib.domain.test.domaintest import DomainTest
+from stoqlib.exceptions import SellError
 from stoqlib.lib.parameters import sysparam
 
 
@@ -69,12 +70,20 @@ class TestSale(DomainTest):
 
     def testSetDiscountByPercentage(self):
         sale = self.create_sale()
-        sellable = self.create_sellable()
+        sellable = self.create_sellable(price=10)
         sale.add_sellable(sellable, quantity=5)
 
-        sale._set_discount_by_percentage(10)
+        sale.discount_percentage = 10
         self.assertEqual(sale.discount_value, currency(5))
 
+        sale = self.create_sale()
+        sellable = self.create_sellable(price=Decimal('1.49'))
+        sale.add_sellable(sellable, quantity=1)
+        sale.discount_percentage = 10
+        # 10% of 1,49 = 0.149, but the calculation should be rounded
+        # since we cannot have 3 decimal points on discount
+        self.assertEqual(sale.discount_value, Decimal('0.15'))
+
     def testGetDiscountByPercentage(self):
         sale = self.create_sale()
         sellable = self.create_sellable()
@@ -89,9 +98,17 @@ class TestSale(DomainTest):
         sellable = self.create_sellable()
         sale.add_sellable(sellable, quantity=5)
 
-        sale._set_surcharge_by_percentage(10)
+        sale.surcharge_percentage = 10
         self.assertEqual(sale.surcharge_value, currency(5))
 
+        sale = self.create_sale()
+        sellable = self.create_sellable(price=Decimal('1.49'))
+        sale.add_sellable(sellable, quantity=1)
+        sale.surcharge_percentage = 10
+        # 10% of 1,49 = 0.149, but the calculation should be rounded
+        # since we cannot have 3 decimal points on surcharge
+        self.assertEqual(sale.surcharge_value, Decimal('0.15'))
+
     def testGetSurchargeByPercentage(self):
         sale = self.create_sale()
         sellable = self.create_sellable()
@@ -208,6 +225,43 @@ class TestSale(DomainTest):
         sale.confirm()
         self.assertEquals(sale.group.payer, sale.client.person)
 
+    def testConfirmQuantityDecreased(self):
+        sale = self.create_sale()
+        branch = sale.branch
+        sellable1 = self.add_product(sale, quantity=10)
+        sellable2 = self.add_product(sale, quantity=10)
+        sellable3 = self.add_product(sale, quantity=10)
+        sale.order()
+        self.add_payments(sale)
+
+        storable1 = sellable1.product_storable
+        storable2 = sellable2.product_storable
+        storable3 = sellable3.product_storable
+        stock1 = storable1.get_balance_for_branch(branch)
+        stock2 = storable2.get_balance_for_branch(branch)
+        stock3 = storable3.get_balance_for_branch(branch)
+
+        # Decrease all stock from 1 and half from 2 and nothing from 3
+        storable1.decrease_stock(10, branch, 0, 0)
+        storable2.decrease_stock(5, branch, 0, 0)
+        # Indicate on the items that those quantities were already decreased
+        for item in sale.get_items():
+            if item.sellable == sellable1:
+                item.quantity_decreased = 10
+            if item.sellable == sellable2:
+                item.quantity_decreased = 5
+
+        sale.confirm()
+
+        # Check that, in the end, everything was decreased by 10,
+        # that is the amount that was sold
+        self.assertEqual(storable1.get_balance_for_branch(branch),
+                         stock1 - 10)
+        self.assertEqual(storable2.get_balance_for_branch(branch),
+                         stock2 - 10)
+        self.assertEqual(storable3.get_balance_for_branch(branch),
+                         stock3 - 10)
+
     def testPay(self):
         sale = self.create_sale()
         self.failIf(sale.can_set_paid())
@@ -595,6 +649,40 @@ class TestSale(DomainTest):
         final_quantity = storable.get_balance_for_branch(sale.branch)
         self.assertEquals(inital_quantity, final_quantity)
 
+    def testCancelDecreasedQuantity(self):
+        sale = self.create_sale()
+        branch = sale.branch
+        sellable1 = self.add_product(sale, quantity=10)
+        sellable2 = self.add_product(sale, quantity=10)
+        sellable3 = self.add_product(sale, quantity=10)
+        sale.order()
+        self.add_payments(sale)
+
+        storable1 = sellable1.product_storable
+        storable2 = sellable2.product_storable
+        storable3 = sellable3.product_storable
+        stock1 = storable1.get_balance_for_branch(branch)
+        stock2 = storable2.get_balance_for_branch(branch)
+        stock3 = storable3.get_balance_for_branch(branch)
+
+        # Decrease all stock from 1 and half from 2 and nothing from 3
+        storable1.decrease_stock(10, branch, 0, 0)
+        storable2.decrease_stock(5, branch, 0, 0)
+        # Indicate on the items that those quantities were already decreased
+        for item in sale.get_items():
+            if item.sellable == sellable1:
+                item.quantity_decreased = 10
+            if item.sellable == sellable2:
+                item.quantity_decreased = 5
+
+        sale.cancel()
+
+        # Check that, in the end, everything was increased by 10,
+        # that is the amount that was marked to be sold
+        self.assertEqual(storable1.get_balance_for_branch(branch), stock1)
+        self.assertEqual(storable2.get_balance_for_branch(branch), stock2)
+        self.assertEqual(storable3.get_balance_for_branch(branch), stock3)
+
     def testCancelPaid(self):
         sale = self.create_sale()
         sellable = self.add_product(sale)
@@ -1038,8 +1126,37 @@ class TestSale(DomainTest):
         sale.surcharge_value = 5
         self.assertEqual(sale.get_total_sale_amount(subtotal), 45)
 
+    def test_get_missing_items(self):
+        sale = self.create_sale()
+
+        stock_item = self.create_sale_item(sale=sale)
+        missing_item = self.create_sale_item(sale=sale)
+
+        stock_storable = self.create_storable(
+            product=stock_item.sellable.product)
+        missing_storable = self.create_storable(
+            product=missing_item.sellable.product)
+
+        self.create_product_stock_item(storable=stock_storable, quantity=1)
+        self.create_product_stock_item(storable=missing_storable, quantity=0)
+
+        missing = sale.get_missing_items()
+
+        self.assertEquals(missing[0].storable, missing_storable)
+
 
 class TestSaleItem(DomainTest):
+    def testSell(self):
+        sale_item = self.create_sale_item()
+        sale_item.sellable.description = u'Product 666'
+
+        with mock.patch.object(sale_item.sellable, 'can_be_sold',
+                               new=lambda: False):
+            with self.assertRaises(SellError) as se:
+                sale_item.sell(branch=sale_item.sale.branch)
+            self.assertEqual(se.exception.message,
+                             u'Product 666 can not be sold.')
+
     def testGetTotal(self):
         sale = self.create_sale()
         product = self.create_product(price=10)
