@@ -42,22 +42,22 @@ from stoqlib.lib.parameters import sysparam
 class TestSellableCategory(DomainTest):
     def setUp(self):
         DomainTest.setUp(self)
-        self._base_category = self._create_category('Monitor')
+        self._base_category = self._create_category(u'Monitor')
 
     def testGetDescription(self):
-        category = self._create_category('LCD', parent=self._base_category)
-        self.assertEqual(category.get_description(), "LCD")
-        self.assertEqual(category.full_description, "Monitor:LCD")
+        category = self._create_category(u'LCD', parent=self._base_category)
+        self.assertEqual(category.get_description(), u"LCD")
+        self.assertEqual(category.full_description, u"Monitor:LCD")
 
-        sub_category = self._create_category("29'", category)
-        self.assertEqual(sub_category.get_description(), "29'")
-        self.assertEqual(sub_category.full_description, "Monitor:LCD:29'")
+        sub_category = self._create_category(u"29'", category)
+        self.assertEqual(sub_category.get_description(), u"29'")
+        self.assertEqual(sub_category.full_description, u"Monitor:LCD:29'")
 
     def testMarkup(self):
         self._base_category.suggested_markup = currency('10')
-        category1 = self._create_category('LCD', parent=self._base_category)
-        category2 = self._create_category('LCD', parent=self._base_category)
-        category3 = self._create_category('LCD', parent=self._base_category)
+        category1 = self._create_category(u'LCD', parent=self._base_category)
+        category2 = self._create_category(u'LCD', parent=self._base_category)
+        category3 = self._create_category(u'LCD', parent=self._base_category)
 
         category1.suggested_markup = None
         category2.suggested_markup = currency(0)
@@ -68,20 +68,20 @@ class TestSellableCategory(DomainTest):
         self.assertEqual(category3.get_markup(), 5)
 
     def testGetBaseCategories(self):
-        categories = SellableCategory.get_base_categories(self.trans)
+        categories = SellableCategory.get_base_categories(self.store)
         count = categories.count()
-        base_category = SellableCategory(description="Monitor",
-                                         connection=self.trans)
-        category = SellableCategory(description="LCD Monitor",
+        base_category = SellableCategory(description=u"Monitor",
+                                         store=self.store)
+        category = SellableCategory(description=u"LCD Monitor",
                                     category=base_category,
-                                    connection=self.trans)
-        categories = SellableCategory.get_base_categories(self.trans)
+                                    store=self.store)
+        categories = SellableCategory.get_base_categories(self.store)
         self.failUnless(base_category in categories)
         self.failIf(category in categories)
         self.assertEqual(categories.count(), count + 1)
 
     def testGetTaxConstant(self):
-        category = self._create_category('LCD', parent=self._base_category)
+        category = self._create_category(u'LCD', parent=self._base_category)
 
         self.assertEquals(category.get_tax_constant(), None)
 
@@ -96,18 +96,18 @@ class TestSellableCategory(DomainTest):
     def _create_category(self, description, parent=None):
         return SellableCategory(description=description,
                                 category=parent,
-                                connection=self.trans)
+                                store=self.store)
 
 
 class TestSellable(DomainTest):
     def setUp(self):
         DomainTest.setUp(self)
-        self._base_category = SellableCategory(description="Cigarro",
-                                               connection=self.trans)
-        self._category = SellableCategory(description="Hollywood",
+        self._base_category = SellableCategory(description=u"Cigarro",
+                                               store=self.store)
+        self._category = SellableCategory(description=u"Hollywood",
                                           category=self._base_category,
                                           suggested_markup=10,
-                                          connection=self.trans)
+                                          store=self.store)
 
     def test_price_based_on_category_markup(self):
         # When the price isn't defined, but the category and the cost. In this
@@ -115,18 +115,18 @@ class TestSellable(DomainTest):
         # markup in the sellable's cost.
         self._category.suggested_markup = 0
         sellable = Sellable(description=u"MX123",
-                            max_discount=0,
                             commission=0,
                             cost=100,
                             category=self._category,
-                            connection=self.trans)
+                            store=self.store)
+        sellable.max_discount = 0
         self.failUnless(sellable.markup == self._category.get_markup(),
-                        ("Expected markup: %r, got %r"
+                        (u"Expected markup: %r, got %r"
                          % (self._category.get_markup(),
                             sellable.markup)))
         price = sellable.cost * (sellable.markup / currency(100) + 1)
         self.failUnless(sellable.price == price,
-                        ("Expected price: %r, got %r"
+                        (u"Expected price: %r, got %r"
                          % (price, sellable.price)))
 
     def test_price_based_on_specified_markup(self):
@@ -136,78 +136,78 @@ class TestSellable(DomainTest):
         markup = 5
         sellable = Sellable(description=u"FY123",
                             category=self._category,
-                            markup=markup,
                             cost=100,
-                            connection=self.trans)
+                            store=self.store)
+        sellable.markup = markup
         self.failUnless(sellable.markup == markup,
-                        ("Expected markup: %r, got %r"
+                        (u"Expected markup: %r, got %r"
                          % (markup, sellable.markup)))
         price = sellable.cost * (markup / currency(100) + 1)
         self.failUnless(sellable.price == price,
-                        ("Expected price: %r, got %r"
+                        (u"Expected price: %r, got %r"
                          % (price, sellable.price)))
 
     def test_commission(self):
         self._category.salesperson_commission = 10
         sellable = Sellable(description=u"TX342",
                             category=self._category,
-                            connection=self.trans)
+                            store=self.store)
         self.failUnless(sellable.commission
                         == self._category.salesperson_commission,
-                        ("Expected salesperson commission: %r, got %r"
+                        (u"Expected salesperson commission: %r, got %r"
                          % (self._category.salesperson_commission,
                             sellable.commission)))
 
     def test_prices_and_markups(self):
         self._category.markup = 0
         sellable = Sellable(category=self._category, cost=50,
-                            description="Test", price=currency(100),
-                            connection=self.trans)
+                            description=u"Test", price=currency(100),
+                            store=self.store)
         self.failUnless(sellable.price == 100,
-                        "Expected price: %r, got %r" % (100, sellable.price))
+                        u"Expected price: %r, got %r" % (100, sellable.price))
         self.failUnless(sellable.markup == 100,
-                        "Expected markup: %r, got %r" % (100, sellable.markup))
+                        u"Expected markup: %r, got %r" % (100, sellable.markup))
         sellable.markup = 10
         self.failUnless(sellable.price == 55,
-                        "Expected price: %r, got %r" % (55, sellable.price))
+                        u"Expected price: %r, got %r" % (55, sellable.price))
         sellable.price = 50
         self.failUnless(sellable.markup == 0,
-                        "Expected markup %r, got %r" % (0, sellable.markup))
+                        u"Expected markup %r, got %r" % (0, sellable.markup))
 
         # When the price specified isn't equivalent to the markup specified.
         # In this case the price don't must be updated based on the markup.
-        sellable = Sellable(markup=10, cost=50,
-                            description="Test", price=currency(100),
-                            connection=self.trans)
+        sellable = Sellable(cost=50,
+                            description=u"Test", price=currency(100),
+                            store=self.store)
         self.failUnless(sellable.price == 100)
 
         # A simple test: product without cost and price, markup must be 0
         sellable.cost = currency(0)
         sellable.price = currency(0)
         self.failUnless(sellable.markup == 0,
-                        "Expected markup %r, got %r" % (0, sellable.markup))
+                        u"Expected markup %r, got %r" % (0, sellable.markup))
 
     def test_get_unblocked_sellables(self):
         # Sellable and query without supplier
         sellable = self.create_sellable()
-        available = Sellable.get_unblocked_sellables(self.trans)
+        available = Sellable.get_unblocked_sellables(self.store)
         self.assertTrue(sellable in list(available))
 
         # Sellable without supplier, but querying with one
         supplier = self.create_supplier()
-        available = Sellable.get_unblocked_sellables(self.trans,
+        available = Sellable.get_unblocked_sellables(self.store,
                                                      supplier=supplier)
         self.assertFalse(sellable in list(available))
 
         # Relate the two
         from stoqlib.domain.product import ProductSupplierInfo
-        ProductSupplierInfo(connection=self.trans,
+        ProductSupplierInfo(store=self.store,
                             supplier=supplier,
                             product=sellable.product,
                             is_main_supplier=True)
 
         # Now the sellable should appear in the results
-        available = Sellable.get_unblocked_sellables(self.trans,
+        available = Sellable.get_unblocked_sellables(self.store,
                                                      supplier=supplier)
         self.assertTrue(sellable in list(available))
 
@@ -236,14 +236,14 @@ class TestSellable(DomainTest):
 
     def testIsValidPrice(self):
         sellable = Sellable(category=self._category, cost=50,
-                            description="Test",
+                            description=u"Test",
                             price=currency(100),
-                            max_discount=0,
-                            connection=self.trans)
-        cat = self.create_client_category('Cat 1')
+                            store=self.store)
+        sellable.max_discount = 0
+        cat = self.create_client_category(u'Cat 1')
         cat_price = ClientCategoryPrice(sellable=sellable, category=cat,
                                         price=150, max_discount=0,
-                                        connection=self.trans)
+                                        store=self.store)
 
         # without a category, and max_discount = 0
         self.assertFalse(sellable.is_valid_price(0))
@@ -276,11 +276,11 @@ class TestSellable(DomainTest):
         self.assertFalse(sellable.is_valid_price(134, cat))
 
     def testGetTaxConstant(self):
-        base_category = SellableCategory(description="Monitor",
-                                         connection=self.trans)
-        category = SellableCategory(description="LCD Monitor",
+        base_category = SellableCategory(description=u"Monitor",
+                                         store=self.store)
+        category = SellableCategory(description=u"LCD Monitor",
                                     category=base_category,
-                                    connection=self.trans)
+                                    store=self.store)
         sellable = self.create_sellable()
         sellable.tax_constant = None
         sellable.category = category
@@ -300,11 +300,9 @@ class TestSellable(DomainTest):
         self.assertEquals(sellable.get_tax_constant(), constant3)
 
     def testClose(self):
-        results_not_closed = ProductFullStockView.select(connection=self.trans)
-        results_with_closed = ProductFullWithClosedStockView.select(
-                                                         connection=self.trans)
-        results_only_closed = ProductClosedStockView.select(
-                                                         connection=self.trans)
+        results_not_closed = self.store.find(ProductFullStockView)
+        results_with_closed = self.store.find(ProductFullWithClosedStockView)
+        results_only_closed = self.store.find(ProductClosedStockView)
         # Count the already there results. ProductClosedStockView should
         # not have any.
         # obs. Using len(list(res)) instead of res.count() because of a bug
@@ -318,11 +316,9 @@ class TestSellable(DomainTest):
         # ProductFullStockView and ProductFullWithClosedStock View,
         # but not on ProductClosedStockView.
         sellable = self.create_sellable()
-        results_not_closed = ProductFullStockView.select(connection=self.trans)
-        results_with_closed = ProductFullWithClosedStockView.select(
-                                                         connection=self.trans)
-        results_only_closed = ProductClosedStockView.select(
-                                                         connection=self.trans)
+        results_not_closed = self.store.find(ProductFullStockView)
+        results_with_closed = self.store.find(ProductFullWithClosedStockView)
+        results_only_closed = self.store.find(ProductClosedStockView)
 
         self.assertEqual(len(list(results_not_closed)), count_not_closed + 1L)
         self.assertEqual(len(list(results_with_closed)), count_with_closed + 1L)
@@ -338,11 +334,10 @@ class TestSellable(DomainTest):
         # ProductClosedStockViewand ProductFullWithClosedStock View,
         # but not on ProductFullStockView.
         sellable.close()
-        results_not_closed = ProductFullStockView.select(connection=self.trans)
-        results_with_closed = ProductFullWithClosedStockView.select(
-                                                         connection=self.trans)
-        results_only_closed = ProductClosedStockView.select(
-                                                         connection=self.trans)
+        results_not_closed = self.store.find(ProductFullStockView)
+        results_with_closed = self.store.find(ProductFullWithClosedStockView)
+        results_only_closed = self.store.find(ProductClosedStockView)
+
         self.assertEquals(sellable.status, Sellable.STATUS_CLOSED)
         self.assertTrue(sellable.is_closed())
         self.assertEqual(len(list(results_not_closed)), count_not_closed)
@@ -363,21 +358,21 @@ class TestSellable(DomainTest):
         sellable = self.create_sellable()
         self.failUnless(sellable.can_close())
 
-        storable = Storable(product=sellable.product, connection=self.trans)
-        storable.increase_stock(1, branch=get_current_branch(self.trans))
+        branch = get_current_branch(self.store)
+        self.create_storable(sellable.product, branch, 1)
         self.failIf(sellable.can_close())
 
         # The delivery service cannot be closed.
-        sellable = sysparam(self.trans).DELIVERY_SERVICE.sellable
+        sellable = sysparam(self.store).DELIVERY_SERVICE.sellable
         self.failIf(sellable.can_close())
 
     def testCanRemove(self):
-        branch = get_current_branch(self.trans)
+        branch = get_current_branch(self.store)
         sellable = self.create_sellable()
-        storable = Storable(product=sellable.product, connection=self.trans)
+        storable = Storable(product=sellable.product, store=self.store)
         self.failUnless(sellable.can_remove())
 
-        storable.increase_stock(1, branch=branch)
+        storable.increase_stock(1, branch, 0, 0)
         sale = self.create_sale()
         sale.status = Sale.STATUS_QUOTE
         sale.branch = branch
@@ -387,9 +382,9 @@ class TestSellable(DomainTest):
         # Can't remove the sellable if it's in a purchase.
         from stoqlib.domain.purchase import PurchaseItem
         sellable = self.create_sellable()
-        Storable(product=sellable.product, connection=self.trans)
+        Storable(product=sellable.product, store=self.store)
         self.assertTrue(sellable.can_remove())
-        PurchaseItem(connection=self.trans,
+        PurchaseItem(store=self.store,
                      quantity=8, quantity_received=0,
                      cost=125, base_cost=125,
                      sellable=sellable,
@@ -397,43 +392,40 @@ class TestSellable(DomainTest):
         self.assertFalse(sellable.can_remove())
 
         # The delivery service cannot be removed.
-        sellable = sysparam(self.trans).DELIVERY_SERVICE.sellable
+        sellable = sysparam(self.store).DELIVERY_SERVICE.sellable
         self.failIf(sellable.can_remove())
 
     def testRemove(self):
         # Remove category price and sellable
         sellable = self.create_sellable()
-        Storable(product=sellable.product, connection=self.trans)
+        Storable(product=sellable.product, store=self.store)
 
         ClientCategoryPrice(sellable=sellable,
                             category=self.create_client_category(),
                             price=100,
-                            connection=self.trans)
+                            store=self.store)
 
-        total = ClientCategoryPrice.selectBy(sellable=sellable.id,
-                                             connection=self.trans).count()
-        total_sellable = Sellable.selectBy(id=sellable.id,
-                                           connection=self.trans).count()
+        total = self.store.find(ClientCategoryPrice, sellable=sellable.id).count()
+        total_sellable = self.store.find(Sellable, id=sellable.id).count()
 
         self.assertEquals(total, 1)
         self.assertEquals(total_sellable, 1)
 
         sellable.remove()
-        total = ClientCategoryPrice.selectBy(sellable=sellable.id,
-                                             connection=self.trans).count()
-        total_sellable = Sellable.selectBy(id=sellable.id,
-                                           connection=self.trans).count()
+        total = self.store.find(ClientCategoryPrice,
+                                sellable=sellable.id).count()
+        total_sellable = self.store.find(Sellable, id=sellable.id).count()
         self.assertEquals(total, 0)
         self.assertEquals(total_sellable, 0)
 
     def test_category_price(self):
         sellable = self.create_sellable(price=100)
-        category1 = self.create_client_category('Cat 1')
+        category1 = self.create_client_category(u'Cat 1')
         category_price = ClientCategoryPrice(sellable=sellable,
                                              category=category1,
                                              price=155,
-                                             connection=self.trans)
-        category2 = self.create_client_category('Cat 2')
+                                             store=self.store)
+        category2 = self.create_client_category(u'Cat 2')
 
         cats = sellable.get_category_prices()
         self.assertEquals(cats.count(), 1)
@@ -446,23 +438,23 @@ class TestSellable(DomainTest):
         from stoqlib.domain.sellable import ClientCategoryPrice
         category_price = self.create_client_category_price()
 
-        total = ClientCategoryPrice.selectBy(connection=self.trans).count()
+        total = self.store.find(ClientCategoryPrice).count()
         self.assertEquals(total, 1)
 
         category_price.remove()
-        total = ClientCategoryPrice.selectBy(connection=self.trans).count()
+        total = self.store.find(ClientCategoryPrice).count()
         self.assertEquals(total, 0)
 
     def test_code(self):
         sellable = self.create_sellable(price=100)
-        sellable.code = 'code'
-        self.assertEquals(sellable.code, 'code')
+        sellable.code = u'code'
+        self.assertEquals(sellable.code, u'code')
         sellable2 = self.create_sellable(price=100)
-        self.assertRaises(SellableError, setattr, sellable2, 'code', 'code')
+        self.assertRaises(SellableError, setattr, sellable2, u'code', u'code')
 
     def test_barcode(self):
         sellable = self.create_sellable(price=100)
-        sellable.barcode = 'barcode'
-        self.assertEquals(sellable.barcode, 'barcode')
+        sellable.barcode = u'barcode'
+        self.assertEquals(sellable.barcode, u'barcode')
         sellable2 = self.create_sellable(price=100)
-        self.assertRaises(SellableError, setattr, sellable2, 'barcode', 'barcode')
+        self.assertRaises(SellableError, setattr, sellable2, u'barcode', u'barcode')
