@@ -26,7 +26,6 @@
 import datetime
 
 from stoqlib.domain.synchronization import BranchSynchronization
-
 from stoqlib.domain.test.domaintest import DomainTest
 
 
@@ -36,27 +35,25 @@ class TestBranchSynchronization(DomainTest):
         self.branch = self.create_branch()
 
     def test_sync(self):
-        results = BranchSynchronization.select(
-            BranchSynchronization.q.branch_id == self.branch.id,
-            connection=self.trans)
+        results = self.store.find(BranchSynchronization,
+                                  branch=self.branch)
         self.assertEqual(results.count(), 0)
 
         t1 = datetime.datetime.now()
         # Datetime columns doesn't store microseconds
         t1 = t1.replace(microsecond=0)
         obj = BranchSynchronization(branch=self.branch,
-                                    policy="shop",
+                                    policy=u"shop",
                                     sync_time=t1,
-                                    connection=self.trans)
+                                    store=self.store)
 
-        results = BranchSynchronization.select(
-            BranchSynchronization.q.branch_id == self.branch.id,
-            connection=self.trans)
+        results = self.store.find(BranchSynchronization,
+                                  branch=self.branch)
         self.assertEqual(results.count(), 1)
         self.assertEqual(results[0], obj)
         # FIXME: Storm is not using the right resolution
         self.assertEqual(obj.sync_time.date(), t1.date())
-        self.assertEqual(obj.policy, "shop")
+        self.assertEqual(obj.policy, u"shop")
         self.assertEqual(obj.branch, self.branch)
 
         t2 = datetime.datetime.now()
@@ -64,12 +61,11 @@ class TestBranchSynchronization(DomainTest):
         t2 = t2.replace(microsecond=0)
         obj.sync_time = t2
 
-        results = BranchSynchronization.select(
-            BranchSynchronization.q.branch_id == self.branch.id,
-            connection=self.trans)
+        results = self.store.find(BranchSynchronization,
+                                  branch=self.branch)
         self.assertEqual(results.count(), 1)
         self.assertEqual(results[0], obj)
         # FIXME: Storm is not using the right resolution
         self.assertEqual(obj.sync_time.date(), t2.date())
-        self.assertEqual(obj.policy, "shop")
+        self.assertEqual(obj.policy, u"shop")
         self.assertEqual(obj.branch, self.branch)
