@@ -43,7 +43,7 @@ from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
-log = Logger('stoqlib.till')
+log = Logger(__name__)
 
 #
 # Domain Classes
