@@ -25,14 +25,18 @@
 
 import datetime
 from kiwi.argcheck import argcheck
+from storm.expr import Join, LeftJoin, Sum
+from storm.info import ClassAlias
+from storm.references import Reference
+from storm.store import AutoReload
 from zope.interface import implements
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import QuantityCol, const, Join, LeftJoin
-from stoqlib.database.orm import ForeignKey, IntCol, Viewable, Alias
-from stoqlib.database.orm import DateTimeCol
+from stoqlib.database.properties import QuantityCol
+from stoqlib.database.properties import IntCol
+from stoqlib.database.properties import DateTimeCol
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
-from stoqlib.domain.product import ProductHistory
+from stoqlib.domain.product import ProductHistory, StockTransactionHistory
 from stoqlib.domain.person import Person, Branch
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.lib.translation import stoqlib_gettext
@@ -45,11 +49,17 @@ class TransferOrderItem(Domain):
 
     """
 
+    __storm_table__ = 'transfer_order_item'
+
+    sellable_id = IntCol()
+
     #: The |sellable| to transfer
-    sellable = ForeignKey('Sellable')
+    sellable = Reference(sellable_id, 'Sellable.id')
+
+    transfer_order_id = IntCol()
 
     #: The |transfer| this item belongs to
-    transfer_order = ForeignKey('TransferOrder')
+    transfer_order = Reference(transfer_order_id, 'TransferOrder.id')
 
     #: The quantity to transfer
     quantity = QuantityCol()
@@ -68,6 +78,8 @@ class TransferOrder(Domain):
     """
     implements(IContainer)
 
+    __storm_table__ = 'transfer_order'
+
     (STATUS_PENDING,
      STATUS_CLOSED) = range(2)
 
@@ -87,25 +99,32 @@ class TransferOrder(Domain):
     #: The date the order was received
     receival_date = DateTimeCol(default_factory=datetime.datetime.now)
 
+    source_branch_id = IntCol()
+
     #: The |branch| sending the stock
-    source_branch = ForeignKey('Branch')
+    source_branch = Reference(source_branch_id, 'Branch.id')
+
+    destination_branch_id = IntCol()
 
     #: The |branch| receiving the stock
-    destination_branch = ForeignKey('Branch')
+    destination_branch = Reference(destination_branch_id, 'Branch.id')
+
+    source_responsible_id = IntCol()
 
     #: The |employee| responsible for the |transfer| at source |branch|
-    source_responsible = ForeignKey('Employee')
+    source_responsible = Reference(source_responsible_id, 'Employee.id')
+
+    destination_responsible_id = IntCol()
 
     #: The |employee| responsible for the |transfer| at destination |branch|
-    destination_responsible = ForeignKey('Employee')
+    destination_responsible = Reference(destination_responsible_id, 'Employee.id')
 
     #
     # IContainer implementation
     #
 
     def get_items(self):
-        return TransferOrderItem.selectBy(transfer_order=self,
-                                          connection=self.get_connection())
+        return self.store.find(TransferOrderItem, transfer_order=self)
 
     def add_item(self, item):
         item.transfer_order = self
@@ -115,8 +134,7 @@ class TransferOrder(Domain):
         if item.transfer_order is not self:
             raise ValueError(_('The item does not belong to this '
                                'transfer order'))
-        TransferOrderItem.delete(item.id,
-                                 connection=self.get_connection())
+        self.store.remove(item)
 
     #
     # Public API
@@ -133,9 +151,11 @@ class TransferOrder(Domain):
         assert self.can_close()
 
         storable = transfer_item.sellable.product_storable
-        storable.decrease_stock(transfer_item.quantity, self.source_branch)
-        conn = self.get_connection()
-        ProductHistory.add_transfered_item(conn, self.source_branch,
+        storable.decrease_stock(transfer_item.quantity, self.source_branch,
+                                StockTransactionHistory.TYPE_TRANSFER_TO,
+                                transfer_item.id)
+        store = self.store
+        ProductHistory.add_transfered_item(store, self.source_branch,
                                            transfer_item)
 
     def receive(self, receival_date=None):
@@ -151,7 +171,8 @@ class TransferOrder(Domain):
             from_stock = storable.get_stock_item(self.source_branch)
             storable.increase_stock(item.quantity,
                                     self.destination_branch,
-                                    from_stock.stock_cost)
+                                    StockTransactionHistory.TYPE_TRANSFER_FROM,
+                                    item.id, unit_cost=from_stock.stock_cost)
         self.status = TransferOrder.STATUS_CLOSED
 
     def get_source_branch_name(self):
@@ -181,36 +202,33 @@ class TransferOrder(Domain):
 
 
 class TransferOrderView(Viewable):
-    BranchDest = Alias(Branch, 'branch_dest')
-    PersonDest = Alias(Person, 'person_dest')
+    BranchDest = ClassAlias(Branch, 'branch_dest')
+    PersonDest = ClassAlias(Person, 'person_dest')
 
-    columns = dict(
-        id=TransferOrder.q.id,
-        identifier=TransferOrder.q.identifier,
-        open_date=TransferOrder.q.open_date,
-        receival_date=TransferOrder.q.receival_date,
-        source_branch_id=TransferOrder.q.source_branch_id,
-        destination_branch_id=TransferOrder.q.destination_branch_id,
-        source_branch_name=Person.q.name,
-        destination_branch_name=PersonDest.q.name,
-        total_itens=const.SUM(TransferOrderItem.q.quantity),
-    )
+    transfer_order = TransferOrder
 
-    joins = [
+    id = TransferOrder.id
+    identifier = TransferOrder.identifier
+    open_date = TransferOrder.open_date
+    receival_date = TransferOrder.receival_date
+    source_branch_id = TransferOrder.source_branch_id
+    destination_branch_id = TransferOrder.destination_branch_id
+    source_branch_name = Person.name
+    destination_branch_name = PersonDest.name
+
+    # Aggregates
+    total_itens = Sum(TransferOrderItem.quantity)
+
+    group_by = [TransferOrder, source_branch_name, destination_branch_name]
+
+    tables = [
+        TransferOrder,
         Join(TransferOrderItem,
-                    TransferOrder.q.id == TransferOrderItem.q.transfer_order_id),
+             TransferOrder.id == TransferOrderItem.transfer_order_id),
         # Source
-        LeftJoin(Branch,
-                   TransferOrder.q.source_branch_id == Branch.q.id),
-        LeftJoin(Person,
-                   Branch.q.person_id == Person.q.id),
+        LeftJoin(Branch, TransferOrder.source_branch_id == Branch.id),
+        LeftJoin(Person, Branch.person_id == Person.id),
         # Destination
-        LeftJoin(BranchDest,
-                   TransferOrder.q.destination_branch_id == BranchDest.q.id),
-        LeftJoin(PersonDest,
-                   BranchDest.q.person_id == PersonDest.q.id),
+        LeftJoin(BranchDest, TransferOrder.destination_branch_id == BranchDest.id),
+        LeftJoin(PersonDest, BranchDest.person_id == PersonDest.id),
     ]
-
-    @property
-    def transfer_order(self):
-        return TransferOrder.get(self.id, self.get_connection())
