@@ -52,7 +52,7 @@ from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
-log = Logger('stoqlib.search')
+log = Logger(__name__)
 
 
 class _SearchDialogDetailsSlave(GladeSlaveDelegate):
@@ -542,6 +542,10 @@ class SearchDialog(BasicDialog):
 
     def _on_results__selection_changed(self, results, selected):
         self.update_widgets()
+        if selected:
+            self.enable_ok()
+        else:
+            self.disable_ok()
 
     def _on_results__row_activated(self, results, obj):
         self.row_activate(obj)
