@@ -58,22 +58,22 @@ class BranchDialog(BaseEditor):
     proxy_widgets = person_widgets + tax_widgets + company_widgets
     model_type = Person
 
-    def __init__(self, trans, model=None):
-        model = create_main_branch(name="", trans=trans).person
+    def __init__(self, store, model=None):
+        model = create_main_branch(name=u"", store=store).person
 
-        self.param = sysparam(trans)
-        BaseEditor.__init__(self, trans, model, visual_mode=False)
+        self.param = sysparam(store)
+        BaseEditor.__init__(self, store, model, visual_mode=False)
         self._setup_widgets()
 
     def _update_system_parameters(self, person):
         icms = self.tax_proxy.model.icms
-        self.param.update_parameter('ICMS_TAX', unicode(icms))
+        self.param.update_parameter(u'ICMS_TAX', unicode(icms))
 
         iss = self.tax_proxy.model.iss
-        self.param.update_parameter('ISS_TAX', unicode(iss))
+        self.param.update_parameter(u'ISS_TAX', unicode(iss))
 
         substitution = self.tax_proxy.model.substitution_icms
-        self.param.update_parameter('SUBSTITUTION_TAX',
+        self.param.update_parameter(u'SUBSTITUTION_TAX',
                                     unicode(substitution))
 
         address = person.get_main_address()
@@ -82,26 +82,26 @@ class BranchDialog(BaseEditor):
                                "this point")
 
         city = address.city_location.city
-        self.param.update_parameter('CITY_SUGGESTED', city)
+        self.param.update_parameter(u'CITY_SUGGESTED', city)
 
         country = address.city_location.country
-        self.param.update_parameter('COUNTRY_SUGGESTED', country)
+        self.param.update_parameter(u'COUNTRY_SUGGESTED', country)
 
         state = address.city_location.state
-        self.param.update_parameter('STATE_SUGGESTED', state)
+        self.param.update_parameter(u'STATE_SUGGESTED', state)
 
         # Update the fancy name
         self.company_proxy.model.fancy_name = self.person_proxy.model.name
 
     def _setup_widgets(self):
         self.name.grab_focus()
-        self.document_l10n = api.get_l10n_field(self.conn, 'company_document')
+        self.document_l10n = api.get_l10n_field(self.store, 'company_document')
         self.cnpj_lbl.set_label(self.document_l10n.label)
         self.cnpj.set_mask(self.document_l10n.entry_mask)
 
     def _setup_slaves(self):
         address = self.model.get_main_address()
-        self._address_slave = AddressSlave(self.conn, self.model, address)
+        self._address_slave = AddressSlave(self.store, self.model, address)
         self.attach_slave("address_holder", self._address_slave)
 
     #
@@ -162,7 +162,7 @@ class BranchDialog(BaseEditor):
 
 def test():  # pragma: no cover
     ec = api.prepare_test()
-    person = run_dialog(BranchDialog, None, ec.trans)
+    person = run_dialog(BranchDialog, None, ec.store)
     print 'RETVAL', person
 
 
