@@ -47,13 +47,14 @@ class DeviceSettingsListSlave(ModelListSlave):
                data_type=bool, width=70)]
     model_type = DeviceSettings
 
+    # FIXME: This should be 'def populate', verify if this is working
     def _populate(self):
-        return DeviceSettings.select(connection=self.parent.trans)
+        return self.parent.store.find(DeviceSettings)
 
-    def run_editor(self, trans, model):
-        return self.run_dialog(DeviceSettingsEditor, conn=trans,
+    def run_editor(self, store, model):
+        return self.run_dialog(DeviceSettingsEditor, store=store,
                                model=model,
-                               station=get_current_station(trans))
+                               station=get_current_station(store))
 
 
 class DeviceSettingsDialog(ModelListDialog):
