@@ -54,7 +54,7 @@ class PaymentCategoryListSlave(ModelListSlave):
                format_func=format_category_type),
         Column('color', title=_('Color'), width=20,
                data_type=gtk.gdk.Pixbuf, format_func=render_pixbuf),
-        Column('color', data_type=str, width=120,
+        Column('color', data_type=unicode, width=120,
                column='color')
         ]
 
@@ -62,18 +62,17 @@ class PaymentCategoryListSlave(ModelListSlave):
         results = super(PaymentCategoryListSlave, self).populate()
 
         if self.parent.category_type is not None:
-            results = results.filterBy(category_type=self.parent.category_type)
+            results = results.find(PaymentCategory.category_type == self.parent.category_type)
 
         return results
 
-    def delete_model(self, model, trans):
-        for payment in Payment.selectBy(category=model,
-                                        connection=trans):
+    def delete_model(self, model, store):
+        for payment in store.find(Payment, category=model):
             payment.category = None
-        PaymentCategory.delete(model.id, connection=trans)
+        store.remove(model)
 
-    def run_editor(self, trans, model):
-        return self.run_dialog(self.editor_class, conn=trans,
+    def run_editor(self, store, model):
+        return self.run_dialog(self.editor_class, store=store,
                                model=model,
                                category_type=self.parent.category_type)
 
@@ -83,10 +82,10 @@ class PaymentCategoryDialog(ModelListDialog):
     size = (620, 300)
     title = _('Payment categories')
 
-    def __init__(self, conn, category_type=None):
+    def __init__(self, store, category_type=None):
         self.category_type = category_type
 
-        ModelListDialog.__init__(self, conn)
+        ModelListDialog.__init__(self, store)
 
         column = self.list_slave.listcontainer.list.get_column_by_name('category_type')
         column.treeview_column.set_visible(category_type is None)
