@@ -33,8 +33,7 @@ from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.gui.base.dialogs import BasicDialog, run_dialog
 from stoqlib.gui.base.search import SearchEditorToolBar
 from stoqlib.gui.editors.paymentmethodeditor import (PaymentMethodEditor,
-                                                     CardPaymentMethodEditor,
-                                                     MoneyPaymentMethodEditor, )
+                                                     CardPaymentMethodEditor)
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -46,19 +45,19 @@ class PaymentMethodsDialog(BasicDialog):
     title = _("Payment Method Settings")
 
     # TODO: implement editor for 'multiple' payment method.
-    METHOD_EDITORS = {'card': CardPaymentMethodEditor,
-                      'money': MoneyPaymentMethodEditor,
-                      'check': PaymentMethodEditor,
-                      'bill': PaymentMethodEditor,
-                      'deposit': PaymentMethodEditor,
-                      'store_credit': PaymentMethodEditor}
+    METHOD_EDITORS = {u'card': CardPaymentMethodEditor,
+                      u'money': PaymentMethodEditor,
+                      u'check': PaymentMethodEditor,
+                      u'bill': PaymentMethodEditor,
+                      u'deposit': PaymentMethodEditor,
+                      u'store_credit': PaymentMethodEditor}
 
-    def __init__(self, conn):
+    def __init__(self, store):
         BasicDialog.__init__(self,
                              hide_footer=True, size=PaymentMethodsDialog.size,
                              title=PaymentMethodsDialog.title)
         self._can_edit = False
-        self.conn = conn
+        self.store = store
         self._setup_list()
         self._setup_slaves()
 
@@ -70,7 +69,7 @@ class PaymentMethodsDialog(BasicDialog):
         self.attach_slave("extra_holder", self._toolbar_slave)
 
     def _setup_list(self):
-        methods = PaymentMethod.get_editable_methods(self.conn)
+        methods = PaymentMethod.get_editable_methods(self.store)
         self.klist = ObjectList(self._get_columns(), methods,
                                 gtk.SELECTION_BROWSE)
         self.klist.connect("selection-changed",
@@ -94,11 +93,11 @@ class PaymentMethodsDialog(BasicDialog):
             raise TypeError('Invalid payment method adapter: %s'
                             % item.method_name)
 
-        trans = api.new_transaction()
-        item = trans.get(item)
-        retval = run_dialog(editor, self, trans, item)
-        api.finish_transaction(trans, retval)
-        trans.close()
+        store = api.new_store()
+        item = store.fetch(item)
+        retval = run_dialog(editor, self, store, item)
+        store.confirm(retval)
+        store.close()
 
     #
     # Callbacks
@@ -107,9 +106,9 @@ class PaymentMethodsDialog(BasicDialog):
     def on_cell_edited(self, klist, obj, attr):
         # All the payment methods could be (de)activate, except the 'money'
         # payment method.
-        if obj.method_name != 'money':
-            conn = obj.get_connection()
-            conn.commit()
+        if obj.method_name != u'money':
+            store = obj.store
+            store.commit()
         else:
             obj.is_active = True
 
