@@ -34,7 +34,7 @@ from stoqlib.api import api
 from stoqlib.database.runtime import get_default_store
 from stoqlib.gui.base.dialogs import BasicDialog, run_dialog
 from stoqlib.gui.stockicons import STOQ_PLUGIN
-from stoqlib.lib.parameters import is_developer_mode
+from stoqlib.lib.environment import is_developer_mode
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.message import yesno
 from stoqlib.lib.pluginmanager import get_plugin_manager
