@@ -30,9 +30,10 @@ from kiwi.currency import currency
 from kiwi.enums import ListType
 from kiwi.ui.objectlist import Column
 from kiwi.ui.listdialog import ListSlave
+from storm.expr import LeftJoin
 
 from stoqlib.api import api
-from stoqlib.database.orm import LeftJoin
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.sellable import (Sellable, ClientCategoryPrice,
                                      SellableCategory)
 from stoqlib.domain.person import ClientCategory
@@ -43,36 +44,22 @@ from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
-from stoqlib.database.orm import Viewable
-
-
-class CategoryPriceView(Viewable):
-    columns = dict(
-        id=ClientCategoryPrice.q.id,
-        sellable_id=ClientCategoryPrice.q.sellable_id,
-        category_id=ClientCategoryPrice.q.category_id,
-        price=ClientCategoryPrice.q.price,
-        max_discount=ClientCategoryPrice.q.max_discount,
-    )
-
 
 class SellableView(Viewable):
-    columns = dict(
-        id=Sellable.q.id,
-        code=Sellable.q.code,
-        barcode=Sellable.q.barcode,
-        status=Sellable.q.status,
-        cost=Sellable.q.cost,
-        category_description=SellableCategory.q.description,
-        description=Sellable.q.description,
-        price=Sellable.q.base_price,
-        max_discount=Sellable.q.max_discount,
-    )
+    id = Sellable.id
+    code = Sellable.code
+    barcode = Sellable.barcode
+    status = Sellable.status
+    cost = Sellable.cost
+    description = Sellable.description
+    price = Sellable.base_price
+    max_discount = Sellable.max_discount
 
-    joins = [
-        # Category
-        LeftJoin(SellableCategory,
-                   SellableCategory.q.id == Sellable.q.category_id),
+    category_description = SellableCategory.description
+
+    tables = [
+        Sellable,
+        LeftJoin(SellableCategory, SellableCategory.id == Sellable.category_id)
     ]
 
     def __init__(self, *args, **kargs):
@@ -90,16 +77,16 @@ class SellableView(Viewable):
         setattr(self, 'price_%s' % category_id, price)
 
     def save_changes(self):
+        store = self.store
         for cat, value in self._new_prices.items():
-            info = ClientCategoryPrice.selectOneBy(sellable_id=self.id,
-                                                category=cat,
-                                                connection=self.get_connection())
+            info = store.find(ClientCategoryPrice, sellable_id=self.id,
+                                                category=cat).one()
             if not info:
                 info = ClientCategoryPrice(sellable_id=self.id,
                                            category=cat,
                                            max_discount=self.max_discount,
                                            price=value,
-                                           connection=self.get_connection())
+                                           store=store)
             else:
                 info.price = value
 
@@ -110,25 +97,24 @@ class SellablePriceDialog(BaseEditor):
     title = _(u"Price Change Dialog")
     size = (850, 450)
 
-    def __init__(self, conn):
-        self.categories = ClientCategory.select(connection=conn)
+    def __init__(self, store):
+        self.categories = store.find(ClientCategory)
         self._last_cat = None
 
-        BaseEditor.__init__(self, conn, model=object())
+        BaseEditor.__init__(self, store, model=object())
         self._setup_widgets()
 
     def _setup_widgets(self):
         self.category.prefill(api.for_combo(self.categories))
 
-        prices = CategoryPriceView.select(connection=self.conn).orderBy(ClientCategoryPrice.q.id)
+        prices = self.store.find(ClientCategoryPrice).order_by(ClientCategoryPrice.id)
         category_prices = {}
         for p in prices:
             c = category_prices.setdefault(p.sellable_id, {})
             c[p.category_id] = p.price
 
         marker('SellableView')
-        sellables = SellableView.select(connection=self.conn)
-        self._sellables = sellables.orderBy(Sellable.q.code)
+        sellables = self.store.find(SellableView).order_by(Sellable.code)
 
         marker('add_items')
         for s in sellables:
