@@ -53,12 +53,12 @@ class StockCostDialog(BaseEditor):
     title = _(u"Product - Stock Cost")
     size = (750, 450)
 
-    def __init__(self, conn, branch=None):
+    def __init__(self, store, branch=None):
         if branch is None:
-            self._branch = api.get_current_branch(conn)
+            self._branch = api.get_current_branch(store)
         else:
             self._branch = branch
-        BaseEditor.__init__(self, conn, model=object())
+        BaseEditor.__init__(self, store, model=object())
         self._setup_widgets()
 
     def _setup_widgets(self):
@@ -66,8 +66,7 @@ class StockCostDialog(BaseEditor):
             _(u"Fixing stock cost for products in <b>%s</b>") %
             api.escape(self._branch.person.name))
 
-        items = ProductWithStockView.select_by_branch(None, branch=self._branch,
-                                                      connection=self.conn)
+        items = ProductWithStockView.find_by_branch(self.store, self._branch)
         self._storables = [_TemporaryItem(s) for s in items]
         self.slave.listcontainer.add_items(self._storables)
 
@@ -80,11 +79,11 @@ class StockCostDialog(BaseEditor):
                         data_type=currency, format_func=get_formatted_cost,
                         editable=True)]
 
-    def _validate_confirm(self, item, trans):
+    def _validate_confirm(self, item, store):
         if (item.stock_cost is not ValueUnset and
             item.stock_cost > 0):
             storable = item.obj.product.storable
-            stock_item = trans.get(storable.get_stock_item(self._branch))
+            stock_item = store.fetch(storable.get_stock_item(self._branch))
             stock_item.stock_cost = item.stock_cost
             self.retval.append(item.obj.product.sellable)
 
@@ -101,12 +100,12 @@ class StockCostDialog(BaseEditor):
 
     def on_confirm(self):
         self.retval = []
-        trans = api.new_transaction()
+        store = api.new_store()
         for item in self._storables:
-            self._validate_confirm(item, trans)
+            self._validate_confirm(item, store)
 
-        api.finish_transaction(trans, True)
-        trans.close()
+        store.confirm(True)
+        store.close()
 
     #
     # Callbacks
