@@ -40,8 +40,10 @@ from stoqlib.domain.sellable import (SellableCategory, Sellable,
                                      ClientCategoryPrice)
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.databaseform import DatabaseForm
+from stoqlib.gui.dialogs.labeldialog import PrintLabelEditor
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.editors.categoryeditor import SellableCategoryEditor
+from stoqlib.gui.printing import print_labels
 from stoqlib.gui.slaves.commissionslave import CommissionSlave
 from stoqlib.lib.formatters import get_price_format_str
 from stoqlib.lib.message import yesno, warning
@@ -75,11 +77,11 @@ class SellableTaxConstantEditor(BaseEditor):
     # BaseEditor
     #
 
-    def create_model(self, conn):
+    def create_model(self, store):
         return SellableTaxConstant(tax_type=int(TaxType.CUSTOM),
                                    tax_value=None,
                                    description=u'',
-                                   connection=conn)
+                                   store=store)
 
 
 class BasePriceEditor(BaseEditor):
@@ -132,10 +134,10 @@ class SellablePriceEditor(BasePriceEditor):
 
     def setup_slaves(self):
         from stoqlib.gui.slaves.sellableslave import OnSaleInfoSlave
-        slave = OnSaleInfoSlave(self.conn, self.model)
+        slave = OnSaleInfoSlave(self.store, self.model)
         self.attach_slave('on_sale_holder', slave)
 
-        commission_slave = CommissionSlave(self.conn, self.model)
+        commission_slave = CommissionSlave(self.store, self.model)
         self.attach_slave('on_commission_data_holder', commission_slave)
         if self.model.category:
             desc = self.model.category.description
@@ -184,25 +186,25 @@ class SellableEditor(BaseEditor):
                         'unit_combo')
     proxy_widgets = (sellable_tax_widgets + sellable_widgets)
 
-    def __init__(self, conn, model=None, visual_mode=False):
+    def __init__(self, store, model=None, visual_mode=False):
         from stoqlib.gui.slaves.sellableslave import CategoryPriceSlave
         is_new = not model
         self._sellable = None
-        self._demo_mode = sysparam(conn).DEMO_MODE
+        self._demo_mode = sysparam(store).DEMO_MODE
         self._requires_weighing_text = (
             "<b>%s</b>" % api.escape(_("This unit type requires weighing")))
 
         if self.ui_form_name:
-            self.db_form = DatabaseForm(conn, self.ui_form_name)
+            self.db_form = DatabaseForm(store, self.ui_form_name)
         else:
             self.db_form = None
-        BaseEditor.__init__(self, conn, model, visual_mode)
+        BaseEditor.__init__(self, store, model, visual_mode)
         self.enable_window_controls()
         if self._demo_mode:
             self._add_demo_warning()
 
         # code suggestion
-        edit_code_product = sysparam(self.conn).EDIT_CODE_PRODUCT
+        edit_code_product = sysparam(self.store).EDIT_CODE_PRODUCT
         self.code.set_sensitive(not edit_code_product and not self.visual_mode)
         if not self.code.read():
             code = u'%d' % self._sellable.id
@@ -221,19 +223,29 @@ class SellableEditor(BaseEditor):
                                     self.tax_hbox,
                                     self.unit_combo,
                                     ])
+
+        print_labels_button = self.add_button('print_labels', gtk.STOCK_PRINT)
+        print_labels_button.connect('clicked', self.on_print_labels_clicked,
+                                    'print_labels')
+        label = print_labels_button.get_children()[0]
+        label = label.get_children()[0].get_children()[1]
+        label.set_label(_(u'Print labels'))
+
         self.setup_widgets()
 
         if not is_new and not self.visual_mode:
-            if self._sellable.is_closed():
+            # Although a sellable can be both removed/closed, we show only one,
+            # to avoid having *lots* of buttons. If it can be removed and
+            # closed, probably the user will prefer to remove
+            if self._sellable.can_remove():
+                self._add_delete_button()
+            elif self._sellable.is_closed():
                 self._add_reopen_button()
             elif self._sellable.can_close():
                 self._add_close_button()
 
-            if self._sellable.can_remove():
-                self._add_delete_button()
-
         self.set_main_tab_label(self.model_name)
-        price_slave = CategoryPriceSlave(self.conn, self.model.sellable,
+        price_slave = CategoryPriceSlave(self.store, self.model.sellable,
                                          self.visual_mode)
         self.add_extra_tab(_(u'Category Prices'), price_slave)
         self._setup_ui_forms()
@@ -243,7 +255,7 @@ class SellableEditor(BaseEditor):
             _("This is a demostration mode of Stoq, you cannot create more than %d products.\n"
               "To avoid this limitation, enable production mode.") % (
             _DEMO_PRODUCT_LIMIT))
-        if Sellable.select(connection=self.conn).count() > _DEMO_PRODUCT_LIMIT:
+        if self.store.find(Sellable).count() > _DEMO_PRODUCT_LIMIT:
             self.disable_ok()
 
     def _add_extra_button(self, label, stock=None,
@@ -311,12 +323,12 @@ class SellableEditor(BaseEditor):
 
     def edit_sale_price(self):
         sellable = self.model.sellable
-        self.conn.savepoint('before_run_editor_sellable_price')
-        result = run_dialog(SellablePriceEditor, self, self.conn, sellable)
+        self.store.savepoint('before_run_editor_sellable_price')
+        result = run_dialog(SellablePriceEditor, self, self.store, sellable)
         if result:
             self.sellable_proxy.update('price')
         else:
-            self.conn.rollback_to_savepoint('before_run_editor_sellable_price')
+            self.store.rollback_to_savepoint('before_run_editor_sellable_price')
 
     def setup_widgets(self):
         raise NotImplementedError
@@ -343,7 +355,7 @@ class SellableEditor(BaseEditor):
         return []
 
     def _fill_categories(self):
-        categories = SellableCategory.select(connection=self.conn)
+        categories = self.store.find(SellableCategory)
         self.category_combo.prefill(api.for_combo(categories,
                                                   attr='full_description'))
 
@@ -363,13 +375,13 @@ class SellableEditor(BaseEditor):
                     [(v, k) for k, v in Sellable.statuses.items()])
         self.statuses_combo.set_sensitive(False)
 
-        cfops = CfopData.select(connection=self.conn)
+        cfops = self.store.find(CfopData)
         self.default_sale_cfop.prefill(api.for_combo(cfops, empty=''))
 
         self.setup_unit_combo()
 
     def setup_unit_combo(self):
-        units = SellableUnit.select(connection=self.conn)
+        units = self.store.find(SellableUnit)
         self.unit_combo.prefill(api.for_combo(units, empty=_('No units')))
 
     def setup_tax_constants(self):
@@ -393,13 +405,13 @@ class SellableEditor(BaseEditor):
         self.update_requires_weighing_label()
 
     def _run_category_editor(self, category=None):
-        self.conn.savepoint('before_run_editor_sellable_category')
-        model = run_dialog(SellableCategoryEditor, self, self.conn, category)
+        self.store.savepoint('before_run_editor_sellable_category')
+        model = run_dialog(SellableCategoryEditor, self, self.store, category)
         if model:
             self._fill_categories()
             self.category_combo.select(model)
         else:
-            self.conn.rollback_to_savepoint('before_run_editor_sellable_category')
+            self.store.rollback_to_savepoint('before_run_editor_sellable_category')
 
     #
     # Kiwi handlers
@@ -489,12 +501,18 @@ class SellableEditor(BaseEditor):
         if value <= 0:
             return ValidationError(_("Cost cannot be zero or negative"))
 
+    def on_print_labels_clicked(self, button, parent_label_button=None):
+        label_data = run_dialog(PrintLabelEditor, None, self.store,
+                                self.model.sellable)
+        if label_data:
+            print_labels(label_data, self.store)
+
 
 def test_sellable_tax_constant():  # pragma nocover
     ec = api.prepare_test()
-    tax_constant = api.sysparam(ec.trans).DEFAULT_PRODUCT_TAX_CONSTANT
+    tax_constant = api.sysparam(ec.store).DEFAULT_PRODUCT_TAX_CONSTANT
     run_dialog(SellableTaxConstantEditor,
-                       parent=None, conn=ec.trans, model=tax_constant)
+                       parent=None, store=ec.store, model=tax_constant)
     print tax_constant
 
 
