@@ -46,6 +46,7 @@ from stoqlib.domain.till import Till
 from stoqlib.drivers.cheque import print_cheques_for_payment_group
 from stoqlib.exceptions import DeviceError, TillError
 from stoqlib.gui.base.dialogs import run_dialog
+from stoqlib.gui.dialogs.quotedialog import ConfirmSaleMissingDialog
 from stoqlib.gui.editors.tilleditor import (TillOpeningEditor,
                                             TillClosingEditor,
                                             TillVerifyEditor)
@@ -60,7 +61,7 @@ from stoqlib.gui.wizards.salewizard import ConfirmSaleWizard
 _ = stoqlib_gettext
 
 
-log = Logger('stoqlib.fiscalprinter')
+log = Logger(__name__)
 
 (CLOSE_TILL_NONE,
  CLOSE_TILL_DB,
@@ -488,6 +489,13 @@ class FiscalCoupon(gobject.GObject):
         model = run_dialog(ConfirmSaleWizard, self._parent, store, sale,
                            subtotal=subtotal,
                            total_paid=total_paid)
+
+        missing = sale.get_missing_items()
+        if missing:
+            run_dialog(ConfirmSaleMissingDialog, self._parent, sale, missing)
+            store.rollback(name=savepoint, close=False)
+            return False
+
         if not model:
             CancelPendingPaymentsEvent.emit()
             store.rollback(name=savepoint, close=False)
