@@ -147,6 +147,28 @@ _bindings = [
     ('app.inventory.inventory_print', '',
      _('Print the product listing for the selected inventory')),
 
+    # Maintenance application
+    ('app.maintenance.new_order', '<control>o',
+     _("Create a new work order")),
+    ('app.maintenance.search_categories', '<control>c',
+     _("Search for categories")),
+    ('app.maintenance.search_products', '<Primary>d',
+     _("Search for products")),
+    ('app.maintenance.search_services', '<Primary>s',
+     _("Search for services")),
+    ('app.maintenance.order_edit', '',
+     _("Edit the selected work order")),
+    ('app.maintenance.order_cancel', '',
+     _("Cancel the selected work order")),
+    ('app.maintenance.order_finish', '',
+     _("Finish the selected work order")),
+    ('app.maintenance.order_details', '',
+     _("Show details for the selected work order")),
+    ('app.maintenance.order_print_quote', '',
+     _("Print a quote report of the selected order")),
+    ('app.maintenance.order_print_receipt', '',
+     _("Print a receipt of the selected order")),
+
     # Payable application
     ('app.payable.add_payable', '<Primary>p',
      _("Create a new account payable")),
@@ -449,8 +471,9 @@ def add_bindings(bindings):
 
 
 def load_user_keybindings():
-    from stoqlib.api import api
-    d = api.user_settings.get('shortcuts', {})
+    from stoqlib.lib.settings import get_settings
+    settings = get_settings()
+    d = settings.get('shortcuts', {})
     for key, value in d.items():
         set_user_binding(key, value)
 
