@@ -34,6 +34,7 @@ from kiwi.ui.objectlist import SearchColumn, Column
 
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.sale import SaleView
+from stoqlib.domain.payment.card import CardPaymentDevice
 from stoqlib.domain.payment.views import (InCheckPaymentView,
                                           OutCheckPaymentView,
                                           CardPaymentView)
@@ -110,6 +111,14 @@ class InPaymentBillCheckSearch(_BaseBillCheckSearch):
 class OutPaymentBillCheckSearch(_BaseBillCheckSearch):
     table = OutCheckPaymentView
 
+    def get_columns(self):
+        columns = _BaseBillCheckSearch.get_columns(self)
+        columns.append(
+            SearchColumn('bill_received', title=_('Bill received'),
+                         data_type=bool, visible=False)
+            )
+        return columns
+
 
 class CardPaymentSearch(SearchDialog):
 
@@ -119,21 +128,28 @@ class CardPaymentSearch(SearchDialog):
     search_table = CardPaymentView
     selection_mode = gtk.SELECTION_BROWSE
 
-    def __init__(self, conn):
-        SearchDialog.__init__(self, conn, self.search_table,
+    def __init__(self, store):
+        SearchDialog.__init__(self, store, self.search_table,
                               title=self.title)
         self.set_details_button_sensitive(False)
         self.results.connect('selection-changed', self.on_selection_changed)
 
-    #
-    #SearchDialogs Hooks
-    #
-
     def _get_status_values(self):
         values = [(v, k) for k, v in Payment.statuses.items()]
         values.insert(0, (_("Any"), None))
         return values
 
+    def _get_device_values(self):
+        devices = CardPaymentDevice.get_devices(self.store)
+        # This is used in a int filter, so we must use the id
+        values = [(d.description, d.id) for d in devices]
+        values.insert(0, (_("Any"), None))
+        return values
+
+    #
+    # SearchDialogs Hooks
+    #
+
     def create_filters(self):
         self.set_text_field_columns(['drawee_name'])
         self.set_searchbar_labels(_(u'Client:'))
@@ -145,14 +161,19 @@ class CardPaymentSearch(SearchDialog):
         self.provider_filter = provider_filter
 
     def get_columns(self):
+        # TODO: Adicionar filtro por card_type
         return [SearchColumn('identifier', title=_('#'), data_type=int,
                              sorted=True, format='%04d', long_title=_('Id')),
                 SearchColumn('description', title=_(u'Description'),
                              data_type=str, expand=True),
                 SearchColumn('drawee_name', title=_(u'Drawee'), data_type=str,
                              expand=True),
-                SearchColumn('provider_name', title=_(u'Credit provider'),
-                             data_type=str, expand=True),
+                SearchColumn('device_name', title=_(u'Card Device'),
+                             data_type=str, visible=False,
+                             search_attribute='device_id',
+                             valid_values=self._get_device_values()),
+                SearchColumn('provider_name', title=_(u'Provider'),
+                             data_type=str),
                 SearchColumn('due_date', title=_(u'Due date'),
                              data_type=datetime.date),
                 SearchColumn('paid_date', title=_(u'Paid date'), visible=False,
@@ -161,15 +182,13 @@ class CardPaymentSearch(SearchDialog):
                              expand=True, search_attribute='status',
                              valid_values=self._get_status_values()),
                 SearchColumn('value', title=_(u'Value'), data_type=currency),
-                SearchColumn('fee', title=_(u'% Fee'),
-                             data_type=Decimal),
-                SearchColumn('fee_calc', title=_(u'Fee'),
-                             data_type=currency)]
+                SearchColumn('fare', title=_(u'Fare'), data_type=currency),
+                SearchColumn('fee', title=_(u'% Fee'), data_type=Decimal),
+                SearchColumn('fee_calc', title=_(u'Fee'), data_type=currency)]
 
-    def executer_query(self, query, having, conn):
+    def executer_query(self, store):
         provider = self.provider_filter.get_state().value
-        return self.search_table.select_by_provider(query, provider,
-                                                    connection=conn)
+        return self.search_table.find_by_provider(store, provider)
 
     def _print_report(self):
         print_report(CardPaymentReport, self.results, list(self.results),
@@ -185,16 +204,14 @@ class CardPaymentSearch(SearchDialog):
 
     def _show_details(self, receivable_view):
         if receivable_view.sale_id is not None:
-            sale_view = SaleView.select(
-                    SaleView.q.id == receivable_view.sale_id,
-                    connection=self.conn)[0]
-            run_dialog(SaleDetailsDialog, self, self.conn, sale_view)
+            sale_view = self.store.find(SaleView, id=receivable_view.sale_id).one()
+            run_dialog(SaleDetailsDialog, self, self.store, sale_view)
         elif receivable_view.renegotiation_id is not None:
-            run_dialog(RenegotiationDetailsDialog, self, self.conn,
+            run_dialog(RenegotiationDetailsDialog, self, self.store,
                        receivable_view.renegotiation)
         else:
             payment = receivable_view.payment
-            run_dialog(LonelyPaymentDetailsDialog, self, self.conn, payment)
+            run_dialog(LonelyPaymentDetailsDialog, self, self.store, payment)
 
     #
     #Callbacks
