@@ -31,9 +31,10 @@ from kiwi.currency import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.ui.search import ComboSearchFilter
 from kiwi.ui.objectlist import SearchColumn
+from storm.expr import Join
 
 from stoqlib.api import api
-from stoqlib.database.orm import Join, Viewable
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.fiscal import CfopData
 from stoqlib.domain.person import Branch
 from stoqlib.domain.payment.group import PaymentGroup
@@ -57,31 +58,25 @@ class TillFiscalOperationsView(Viewable):
     :attribute station_name: the value of name branch_station name column
     """
 
-    columns = dict(
-        id=Payment.q.id,
-        identifier=Payment.q.identifier,
-        date=Payment.q.open_date,
-        description=Payment.q.description,
-        value=Payment.q.value,
-        cfop=CfopData.q.code,
-        station_name=BranchStation.q.name,
-        branch_id=Branch.q.id,
-        status=Till.q.status,
-        )
+    id = Payment.id
+    identifier = Payment.identifier
+    date = Payment.open_date
+    description = Payment.description
+    value = Payment.value
 
-    joins = [
-        Join(Till,
-                    Till.q.id == Payment.q.till_id),
-        Join(BranchStation,
-                    BranchStation.q.id == Till.q.station_id),
-        Join(Branch,
-                    Branch.q.id == BranchStation.q.branch_id),
-        Join(PaymentGroup,
-                    PaymentGroup.q.id == Payment.q.group_id),
-        Join(Sale,
-                    Sale.q.group_id == PaymentGroup.q.id),
-        Join(CfopData,
-                    CfopData.q.id == Sale.q.cfop_id),
+    cfop = CfopData.code
+    station_name = BranchStation.name
+    branch_id = Branch.id
+    status = Till.status
+
+    tables = [
+        Payment,
+        Join(Till, Till.id == Payment.till_id),
+        Join(BranchStation, BranchStation.id == Till.station_id),
+        Join(Branch, Branch.id == BranchStation.branch_id),
+        Join(PaymentGroup, PaymentGroup.id == Payment.group_id),
+        Join(Sale, Sale.group_id == PaymentGroup.id),
+        Join(CfopData, CfopData.id == Sale.cfop_id),
         ]
 
 
@@ -131,5 +126,5 @@ class TillFiscalOperationsSearch(SearchDialog):
     #
 
     def _get_query(self, state):
-        branch = api.get_current_branch(self.conn)
-        return self.search_table.q.branch_id == branch.id
+        branch = api.get_current_branch(self.store)
+        return self.search_table.branch_id == branch.id
