@@ -55,13 +55,13 @@ class SaleDiscountSlave(BaseEditorSlave):
                      'discount_perc', )
     gsignal('discount-changed')
 
-    def __init__(self, conn, model, model_type, visual_mode=False):
+    def __init__(self, store, model, model_type, visual_mode=False):
         self._proxy = None
         self.model = model
         self.model_type = model_type
-        self.default_max_discount = sysparam(conn).MAX_SALE_DISCOUNT
+        self.default_max_discount = sysparam(store).MAX_SALE_DISCOUNT
         self.max_discount = self.default_max_discount
-        BaseEditorSlave.__init__(self, conn, model, visual_mode=visual_mode)
+        BaseEditorSlave.__init__(self, store, model, visual_mode=visual_mode)
 
     def setup_widgets(self):
         format_str = get_price_format_str()
@@ -74,6 +74,7 @@ class SaleDiscountSlave(BaseEditorSlave):
         self.discount_perc.set_sensitive(not discount_by_value)
 
     def update_max_discount(self):
+        old_max_discount = self.max_discount
         self.max_discount = self.default_max_discount
 
         client = self.model.client
@@ -81,8 +82,11 @@ class SaleDiscountSlave(BaseEditorSlave):
             self.max_discount = max(client.category.max_discount,
                                     self.default_max_discount)
 
-        self.discount_value.validate()
-        self.discount_perc.validate()
+        # Avoid re-validating if the validation parameters didnt change, since
+        # that is doint to many queries right now.
+        if old_max_discount != self.max_discount:
+            self.discount_value.validate()
+            self.discount_perc.validate()
 
     def update_sale_discount(self):
         if self._proxy is None:
@@ -95,6 +99,7 @@ class SaleDiscountSlave(BaseEditorSlave):
         self.emit('discount-changed')
 
     def _validate_percentage(self, value, type_text):
+        old_discount = self.model.discount_value
         if value >= 100:
             self.model.discount_percentage = 0
             return ValidationError(_(u'%s can not be greater or equal '
@@ -107,7 +112,10 @@ class SaleDiscountSlave(BaseEditorSlave):
             self.model.discount_percentage = 0
             return ValidationError(_("%s can not be less then 0")
                                     % type_text)
-        self.update_sale_discount()
+
+        # Avoid unecessary updates if the discount didnt change
+        if self.model.discount_value != old_discount:
+            self.update_sale_discount()
 
     def set_max_discount(self, discount):
         """Set the maximum percentage value for a discount.
@@ -156,8 +164,8 @@ class SaleListToolbar(GladeSlaveDelegate):
     gsignal('sale-returned', object)
     gsignal('sale-edited', object)
 
-    def __init__(self, conn, sales, parent=None):
-        self.conn = conn
+    def __init__(self, store, sales, parent=None):
+        self.store = store
         if sales.get_selection_mode() != gtk.SELECTION_BROWSE:
             raise TypeError("Only SELECTION_BROWSE mode for the "
                             "list is supported on this slave")
@@ -188,11 +196,11 @@ class SaleListToolbar(GladeSlaveDelegate):
     def edit(self, sale_view=None):
         if sale_view is None:
             sale_view = self.sales.get_selected()
-        trans = api.new_transaction()
-        sale = trans.get(sale_view.sale)
-        model = run_dialog(SaleQuoteWizard, self.parent, trans, sale)
-        retval = api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        sale = store.fetch(sale_view.sale)
+        model = run_dialog(SaleQuoteWizard, self.parent, store, sale)
+        retval = store.confirm(model)
+        store.close()
 
         if retval:
             self.emit('sale-edited', retval)
@@ -201,20 +209,21 @@ class SaleListToolbar(GladeSlaveDelegate):
         if sale_view is None:
             sale_view = self.sales.get_selected()
         run_dialog(SaleDetailsDialog, self.parent,
-                   self.conn, sale_view)
+                   self.store, sale_view)
 
     def print_sale(self):
         print_report(SalesReport, self.sales, list(self.sales),
                      filters=self._report_filters)
 
     def return_sale(self):
-        assert not Inventory.has_open(self.conn,
-                            api.get_current_branch(self.conn))
-        sale = self.sales.get_selected()
-        trans = api.new_transaction()
-        retval = return_sale(self.get_parent(), sale, trans)
-        api.finish_transaction(trans, retval)
-        trans.close()
+        assert not Inventory.has_open(self.store,
+                            api.get_current_branch(self.store))
+        sale_view = self.sales.get_selected()
+        store = api.new_store()
+        retval = return_sale(self.get_parent(),
+                             store.fetch(sale_view.sale), store)
+        store.confirm(retval)
+        store.close()
 
         if retval:
             self.emit('sale-returned', retval)
@@ -264,9 +273,8 @@ def cancel_sale(sale):
     return False
 
 
-def return_sale(parent, sale_view, conn):
+def return_sale(parent, sale, store):
     from stoqlib.gui.wizards.salereturnwizard import SaleReturnWizard
-    sale = Sale.get(sale_view.id, connection=conn)
     if ECFIsLastSaleEvent.emit(sale):
         info(_("That is last sale in ECF. Return using the menu "
                "ECF - Cancel Last Document"))
@@ -274,7 +282,7 @@ def return_sale(parent, sale_view, conn):
 
     if sale.can_return():
         returned_sale = sale.create_sale_return_adapter()
-        retval = run_dialog(SaleReturnWizard, parent, conn, returned_sale)
+        retval = run_dialog(SaleReturnWizard, parent, store, returned_sale)
     elif sale.can_cancel():
         retval = cancel_sale(sale)
     else:
