@@ -151,7 +151,8 @@ icon_info = [
     (STOQ_SALES_APP,
      {GTK_ICON_SIZE_DIALOG: "stoq-sales-app-48x48.png"}),
     (STOQ_SERVICES,
-     {GTK_ICON_SIZE_DIALOG: "stoq-services-48x48.png"}),
+     {GTK_ICON_SIZE_LARGE_TOOLBAR: "stoq-services-24x24.png",
+      GTK_ICON_SIZE_DIALOG: "stoq-services-48x48.png"}),
     (STOQ_STOCK_APP,
      {GTK_ICON_SIZE_MENU: "stoq-stock-app-16x16.png",
       GTK_ICON_SIZE_LARGE_TOOLBAR: "stoq-stock-app-24x24.png",
