@@ -30,6 +30,6 @@ from stoqlib.gui.editors.producteditor import ProductionProductEditor
 class TestProductionProductEditor(GUITest):
     def testShow(self):
         product = self.create_product()
-        editor = ProductionProductEditor(self.trans, product)
+        editor = ProductionProductEditor(self.store, product)
         editor.code.update("12345")
         self.check_editor(editor, 'editor-productionproduct-show')
