@@ -31,5 +31,5 @@ class TestProductSupplierEditor(GUITest):
     def testShow(self):
         product = self.create_product(create_supplier=True)
         supplier_info = product.get_main_supplier_info()
-        editor = ProductSupplierEditor(self.trans, supplier_info)
+        editor = ProductSupplierEditor(self.store, supplier_info)
         self.check_editor(editor, 'editor-productsupplier-show')
