@@ -30,7 +30,7 @@ from stoqlib.gui.editors.receivingeditor import ReceivingItemEditor
 class TestReceivingItemEditor(GUITest):
     def testShow(self):
         item = self.create_receiving_order_item()
-        editor = ReceivingItemEditor(self.trans, item)
+        editor = ReceivingItemEditor(self.store, item)
         editor.receiving_order.set_label("12345")
         editor.purchase_order.set_label("12345")
         self.check_editor(editor, 'editor-receivingitem-show')
