@@ -69,6 +69,32 @@ class TestConfirmSaleWizard(GUITest):
 
         self.check_wizard(self.wizard, name, models=models)
 
+    def testQueries(self):
+        sale = self.create_sale()
+        sale.identifier = 12345
+        self.add_product(sale, price=10)
+
+        self.sale = sale
+        total = sale.get_total_sale_amount()
+
+        with self.count_tracer() as tracer:
+            self.wizard = ConfirmSaleWizard(self.store, sale,
+                                            subtotal=total,
+                                            total_paid=0)
+
+        # NOTE: Document increases/decreases
+        # 3: select user/branch/station (normally cached)
+        # 1: select sales_person
+        # 4: select parameters
+        # 1: select client
+        # 1: select transporter
+        # 1: select cost cebnter
+        # 2: select invoice number
+        # 1: select payment method
+        # 2: select sale_item
+        # 1: select payment status
+        self.assertEquals(tracer.count, 17)
+
     def testCreate(self):
         self._create_wizard()
         self._go_to_next()
@@ -88,6 +114,21 @@ class TestConfirmSaleWizard(GUITest):
         # Since $30 was already paid, the client only had to pay $70
         self.assertEquals(self.sale.payments[0].value, 7)
 
+    def testSaleWithTradeSameValue(self):
+        self._create_wizard(total_paid=10)
+        self._go_to_next()
+
+        self.assertFalse(self.wizard.need_create_payment())
+        self.assertNotVisible(self.step, ['select_method_holder',
+                                          'subtotal_expander'])
+        self.assertNotSensitive(self.step.cash_change_slave,
+                                ['received_value'])
+
+        self._check_wizard('wizard-sale-with-trade-same-value')
+
+        # No payment created, since the client already paid the whole value
+        self.assertEquals(self.sale.payments.count(), 0)
+
     @mock.patch('stoqlib.gui.wizards.salewizard.yesno')
     def testSaleWithCostCenter(self, yesno):
         cost_center = self.create_cost_center()
