@@ -24,11 +24,11 @@
 
 import datetime
 import locale
+import os
 import unittest
 
 from dateutil import relativedelta
 from dateutil.relativedelta import SU, MO, SA, relativedelta as delta
-from nose.exc import SkipTest
 
 from kiwi.ui.objectlist import SearchColumn
 from kiwi.ui.search import (StringSearchFilter, DateSearchFilter,
@@ -44,9 +44,11 @@ from stoqlib.lib.introspection import get_all_classes
 
 
 class TestDateOptions(unittest.TestCase):
+    def setUp(self):
+        self._original_locale = locale.getlocale(locale.LC_ALL)
 
     def tearDown(self):
-        self._set_locale("")
+        self._set_locale(self._original_locale)
 
     def _get_week_interval(self, today):
         weekday = get_weekday_start()
@@ -62,19 +64,21 @@ class TestDateOptions(unittest.TestCase):
     def _get_locales(self):
         # en_US: week starts on sunday
         # es_ES: week starts on monday
-        return ["en_US", "es_ES"]
+        return ["en_US.UTF-8", "es_ES.UTF-8"]
 
     def _starts_on_sunday(self, loc):
-        return loc == "en_US"
+        return loc.startswith("en_US")
 
     def _set_locale(self, loc):
         try:
-            locale.setlocale(locale.LC_ALL, loc)
+            loc = locale.setlocale(locale.LC_ALL, loc)
         except locale.Error:
             # Some locales could not be available on user's machine, leading
             # him to a false positive broke test, so skip it, informing the
             # problem.
             raise unittest.SkipTest("Locale %s not available" % (loc, ))
+        else:
+            os.environ['LC_ALL'] = loc
 
     def _testWeekday(self, loc, interval):
         if self._starts_on_sunday(loc):
@@ -89,7 +93,6 @@ class TestDateOptions(unittest.TestCase):
                 relativedelta.weekday(interval[1].weekday()), SU)
 
     def testThisWeek(self):
-        raise SkipTest("Segmentation fault in jenkins")
         option = ThisWeek()
         for loc in self._get_locales():
             self._set_locale(loc)
@@ -102,7 +105,6 @@ class TestDateOptions(unittest.TestCase):
                 self._testWeekday(loc, option.get_interval())
 
     def testLastWeek(self):
-        raise SkipTest("Segmentation fault in jenkins")
         option = LastWeek()
         for loc in self._get_locales():
             self._set_locale(loc)
@@ -117,7 +119,6 @@ class TestDateOptions(unittest.TestCase):
                 self._testWeekday(loc, option.get_interval())
 
     def testNextWeek(self):
-        raise SkipTest("Segmentation fault in jenkins")
         option = NextWeek()
         for loc in self._get_locales():
             self._set_locale(loc)
@@ -132,7 +133,6 @@ class TestDateOptions(unittest.TestCase):
                 self._testWeekday(loc, option.get_interval())
 
     def testThisMonth(self):
-        raise SkipTest("Segmentation fault in jenkins")
         option = ThisMonth()
         for loc in self._get_locales():
             self._set_locale(loc)
@@ -145,7 +145,6 @@ class TestDateOptions(unittest.TestCase):
                                  self._get_month_interval(month_day))
 
     def testLastMonth(self):
-        raise SkipTest("Segmentation fault in jenkins")
         option = LastMonth()
         for loc in self._get_locales():
             self._set_locale(loc)
@@ -177,11 +176,10 @@ class TestSearchGeneric(DomainTest):
 
     # Those are base classes for other searches, and should not be instanciated
     ignored_classes = [
-        '_SellableSearch',
+        'AdvancedSellableSearch',
         '_BaseBillCheckSearch',
         'SearchEditor',
         'BasePersonSearch',
-        'AbstractCreditProviderSearch',
     ]
 
     @classmethod
@@ -190,7 +188,7 @@ class TestSearchGeneric(DomainTest):
             try:
                 if klass.__name__ in cls.ignored_classes:
                     continue
-                # Exclude Viewable, since we just want to test it's subclasses
+                # Exclude SearchDialog, since we just want to test it's subclasses
                 if not issubclass(klass, SearchDialog) or klass is SearchDialog:
                     continue
             except TypeError:
@@ -199,11 +197,11 @@ class TestSearchGeneric(DomainTest):
             yield klass
 
     def _test_search(self, search_class):
-        # XXX: If we use self.trans, the all this tests passes, but the test
+        # XXX: If we use self.store, the all this tests passes, but the test
         # executed after this will break with
         # storm.exceptions.ClosedError('Connection is closed',)
-        trans = api.new_transaction()
-        search = search_class(trans)
+        store = api.new_store()
+        search = search_class(store)
 
         # There may be no results in the search, but we only want to check if
         # the query is executed properly
@@ -239,7 +237,7 @@ class TestSearchGeneric(DomainTest):
             # Remove the filter so it wont affect other searches
             filter.emit('removed')
 
-        trans.close()
+        store.close()
 
 
 for search in TestSearchGeneric._get_all_searches():
