@@ -212,10 +212,7 @@ class LoanItemStep(SaleQuoteItemStep):
     model_type = Loan
     item_table = LoanItem
     sellable_view = ProductFullStockItemView
-
-    def post_init(self):
-        SaleQuoteItemStep.post_init(self)
-        self.slave.set_editor(LoanItemEditor)
+    item_editor = LoanItemEditor
 
     def _has_stock(self, sellable, quantity):
         storable = sellable.product_storable
@@ -399,6 +396,7 @@ class LoanItemSelectionStep(SellableItemStep):
         return any_changed
 
     def validate(self, value):
+        super(LoanItemSelectionStep, self).validate(value)
         self.wizard.refresh_next(value and self.validate_step())
 
     #
@@ -545,7 +543,9 @@ class CloseLoanWizard(BaseWizard):
                 coupon_id=None)
 
             for sellable, quantity, price in self._sold_items:
-                sale.add_sellable(sellable, quantity, price)
+                sale.add_sellable(sellable, quantity, price,
+                                  # Quantity was already decreased on loan
+                                  quantity_decreased=quantity)
 
             sale.order()
             info(_("Close loan details..."),
