@@ -39,11 +39,11 @@ from stoqlib.exceptions import StoqlibError
 from stoqlib.database.runtime import get_default_store
 from stoqlib.lib.interfaces import IAppInfo
 from stoqlib.lib.osutils import get_system_locale
-from stoqlib.lib.parameters import is_developer_mode
+from stoqlib.lib.environment import is_developer_mode
 from stoqlib.lib.uptime import get_uptime
 from stoqlib.lib.webservice import WebService
 
-log = Logger('stoqlib.crashreporter')
+log = Logger(__name__)
 _tracebacks = []
 
 _N_TRIES = 3
