@@ -7,7 +7,6 @@ from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.fiscal import CfopData
 from stoqlib.domain.inventory import Inventory, InventoryItem
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.product import Storable
 from stoqlib.domain.sellable import SellableTaxConstant
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.lib.sintegragenerator import StoqlibSintegraGenerator
@@ -29,35 +28,35 @@ class TestSintegraGenerator(DomainTest):
         order.expense_value = 12
         supplier = self.create_supplier()
         company = supplier.person.has_individual_or_company_facets()
-        company.state_registry = '103238426117'
+        company.state_registry = u'103238426117'
         order.supplier = supplier
         employee = self.create_employee()
-        branch = get_current_branch(self.trans)
+        branch = get_current_branch(self.store)
         branch.manager = employee
 
         order.purchase.status = order.purchase.ORDER_PENDING
 
         sellable = self.create_sellable()
         sellable.tax_constant = SellableTaxConstant(
-            description="18",
+            description=u"18",
             tax_type=int(TaxType.CUSTOM),
             tax_value=18,
-            connection=self.trans)
+            store=self.store)
         self.create_receiving_order_item(order, sellable=sellable)
 
         sellable2 = self.create_sellable()
         sellable2.tax_constant = SellableTaxConstant(
-            description="6",
+            description=u"6",
             tax_type=int(TaxType.CUSTOM),
             tax_value=6,
-            connection=self.trans)
+            store=self.store)
         self.create_receiving_order_item(order, sellable=sellable2)
 
         order.purchase.confirm()
         order.confirm()
 
-        sellable.code = '9999'
-        sellable2.code = '10000'
+        sellable.code = u'9999'
+        sellable2.code = u'10000'
 
         sale = self.create_sale()
         sale.open_date = datetime.date(2007, 6, 10)
@@ -65,20 +64,18 @@ class TestSintegraGenerator(DomainTest):
         sellable3 = self.create_sellable()
         product = sellable3.product
         sellable.tax_constant = SellableTaxConstant(
-            description="18",
+            description=u"18",
             tax_type=int(TaxType.CUSTOM),
             tax_value=18,
-            connection=self.trans)
+            store=self.store)
 
         sale.add_sellable(sellable3, quantity=1)
 
-        storable = Storable(product=product,
-                            connection=self.trans)
-        storable.increase_stock(100, get_current_branch(self.trans))
+        self.create_storable(product, get_current_branch(self.store), stock=100)
 
         sale.order()
 
-        method = PaymentMethod.get_by_name(self.trans, 'money')
+        method = PaymentMethod.get_by_name(self.store, u'money')
         method.create_inpayment(sale.group, sale.branch,
                                 sale.get_sale_subtotal())
 
@@ -86,9 +83,9 @@ class TestSintegraGenerator(DomainTest):
         sale.set_paid()
         sale.close_date = datetime.date(2007, 6, 10)
         sale.confirm_date = datetime.date(2007, 6, 10)
-        sellable3.code = '09999'
+        sellable3.code = u'09999'
 
-        inventory = Inventory(branch=branch, connection=self.trans)
+        inventory = Inventory(branch=branch, store=self.store)
         inventory.open_date = datetime.date(2007, 6, 15)
 
         # product came from sellable3
@@ -96,14 +93,14 @@ class TestSintegraGenerator(DomainTest):
                                        product_cost=product.sellable.cost,
                                        inventory=inventory,
                                        recorded_quantity=99,
-                                       connection=self.trans)
-        inventory_item.cfop_data = CfopData.get(1, connection=self.trans)
-        inventory_item.reason = 'Test'
+                                       store=self.store)
+        inventory_item.cfop_data = self.store.get(CfopData, 1)
+        inventory_item.reason = u'Test'
         inventory_item.actual_quantity = 99
         inventory_item.adjust(invoice_number=999)
         inventory.close(close_date=datetime.date(2007, 6, 15))
 
-        generator = StoqlibSintegraGenerator(self.trans,
+        generator = StoqlibSintegraGenerator(self.store,
                                              datetime.date(2007, 6, 1),
                                              datetime.date(2007, 6, 30))
 
