@@ -29,6 +29,10 @@ import random
 import socket
 
 
+def get_hostname():
+    return unicode(socket.gethostname())
+
+
 def get_random_port():
     i = 0
     while True:
