@@ -772,8 +772,8 @@ class BillReport(object):
     def validate_payment_for_printing(cls, payment):
         account = payment.method.destination_account
         if not account:
-            msg = _("Payment method missing a destination account: '%s'" % (
-                account.description, ))
+            msg = _("Payment method missing a destination account: '%s'") % (
+                account.description, )
             return msg
 
         from stoqlib.domain.account import Account
@@ -786,7 +786,7 @@ class BillReport(object):
 
         bank = account.bank
         if bank.bank_number == 0:
-            msg = _("Improperly configured bank account: %r" % (bank, ))
+            msg = _("Improperly configured bank account: %r") % (bank, )
             return msg
 
         # FIXME: Verify that all bill option fields are configured properly
@@ -794,7 +794,7 @@ class BillReport(object):
         bank_no = bank.bank_number
         bank_info = get_bank_info_by_number(bank_no)
         if not bank_info:
-            msg = _("Missing stoq support for bank %d" % (bank_no, ))
+            msg = _("Missing stoq support for bank %d") % (bank_no, )
             return msg
 
     def _get_bill(self):
@@ -805,7 +805,7 @@ class BillReport(object):
 
     def _get_instrucoes(self, payment):
         instructions = []
-        data = sysparam(payment.get_connection()).BILL_INSTRUCTIONS
+        data = sysparam(payment.store).BILL_INSTRUCTIONS
         for line in data.split('\n')[:3]:
             line = line.replace('$DATE', payment.due_date.strftime('%d/%m/%Y'))
             instructions.append(line)
@@ -836,7 +836,7 @@ class BillReport(object):
         if parent:
             branch = parent.branch
         else:
-            branch = sysparam(payment.get_connection()).MAIN_COMPANY
+            branch = sysparam(payment.store).MAIN_COMPANY
         return branch.get_description()
 
     def _get_account(self, payment):
